@@ -39,9 +39,9 @@ OC.L10N.register(
     "You cancelled {member}'s invitation to join {circle}" : "Você cancelou o convite de {member} para juntar-se a {circle}",
     "Your invitation to join {circle} has been cancelled by {author}" : "Seu convite para juntar-se a {circle} foi cancelado por {author}",
     "{author} cancelled {member}'s invitation to join {circle}" : "{author} cancelou o convite de {member} para juntar-se a {circle}",
-    "You dismissed {member}'s request to join {circle}" : "Você descartou a solicitação de {member} para juntar-se à {circle}",
-    "Your request to join {circle} has been dismissed by {author}" : "Sua solicitação para juntar-se à {circle} foi descartada por {author}",
-    "{member}'s request to join {circle} has been dismissed by {author}" : "A solicitação de {member} para juntar-se à {circle} foi descartada por {author}",
+    "You dismissed {member}'s request to join {circle}" : "Você dispensou a solicitação de {member} para entrar em {circle}",
+    "Your request to join {circle} has been dismissed by {author}" : "Sua solicitação para entrar em {circle} foi dispensada por {author}",
+    "{member}'s request to join {circle} has been dismissed by {author}" : "A solicitação de {member} para entrar em {circle} foi dispensada por {author}",
     "You invited {member} to join {circle}" : "Você convidou {member} a juntar-se à {circle}",
     "You have been invited to join {circle} by {author}" : "Você foi convidado a juntar-se à {circle} por {author}",
     "{member} has been invited to join {circle} by {author}" : "{member} foi convidado a juntar-se à {circle} por {author}",
@@ -134,6 +134,7 @@ OC.L10N.register(
     "You have no permission to create a new team" : "Você não tem permissão para criar uma nova equipe",
     "%s shared a file with \"%s\"." : "%s compartilhou um arquivo com \"%s\".",
     "%s shared a file with you." : "%s compartilhou um arquivo com você.",
+    "Open %s" : "Abrir %s",
     "%1$s shared some content with you.\nYou should have already received a separate email with a link to access it.\n" : "%1$s compartilhou algum conteúdo com você.\nVocê já deve ter recebido um e-mail separado com um link para acessá-lo.\n",
     "%1$s shared some content with you. You should have already received a separate email with a link to access it." : "%1$s compartilhou algum conteúdo com você. Você já deve ter recebido um e-mail separado com um link para acessá-lo.",
     "Password to access content shared with you by %1$s" : "Senha para acessar o conteúdo compartilhado com você por %1$s",
@@ -151,11 +152,6 @@ OC.L10N.register(
     "No teams found" : "Nenhuma equipe encontrada",
     "Please select teams to filter by" : "Selecione equipes para filtrar",
     "No files found for the selected teams" : "Nenhum arquivo encontrado para as equipes selecionadas",
-    "{author} added team {member} has been added as member to {circle}" : "{author} adicionou a equipe {member} como membro de {circle}",
-    "Shared to Circles" : "Compartilhado com Círculos",
-    "You are now a member of the Circle \"%2$s\"" : "Agora você é membro do Círculo \"%2$s\"",
-    "You have been invited by %1$s into the Circle \"%2$s\"" : "Você foi convidado por %1$s para o Círculo \"%2$s\"",
-    "%1$s sent a request to be a member of the Circle \"%2$s\"" : "%1$s solicitou ser membro do Círculo \"%2$s\"",
-    "Leave the circle" : "Sair do círculo"
+    "Shared to Circles" : "Compartilhado com Círculos"
 },
 "nplurals=3; plural=(n == 0 || n == 1) ? 0 : n != 0 && n % 1000000 == 0 ? 1 : 2;");
