@@ -250,6 +250,8 @@ OC.L10N.register(
     "Completed on %s" : "%sに完了",
     "Due on %s by %s" : "期限日%s が%sにより設定",
     "Due on %s" : "期限日：%s",
+    "Welcome to Nextcloud Calendar!\n\nThis is a sample event - explore the flexibility of planning with Nextcloud Calendar by making any edits you want!\n\nWith Nextcloud Calendar, you can:\n- Create, edit, and manage events effortlessly.\n- Create multiple calendars and share them with teammates, friends, or family.\n- Check availability and display your busy times to others.\n- Seamlessly integrate with apps and devices via CalDAV.\n- Customize your experience: schedule recurring events, adjust notifications and other settings." : "Nextcloudカレンダーへようこそ！\n\nNextcloudカレンダーの柔軟なプランニングをお試しください！\n\nNextcloudカレンダーなら、こんなことができます：\n- イベントを簡単に作成、編集、管理できます。\n- 複数のカレンダーを作成し、チームメイトや友人、家族と共有できます。\n- 空き時間を確認し、忙しい時間を他の人に表示する。\n- CalDAV経由でアプリやデバイスとシームレスに統合。\n- 定期的なイベントのスケジュール、通知やその他の設定など、エクスペリエンスをカスタマイズできます。",
+    "Example event - open me!" : "イベント例 - 開いてください!",
     "System Address Book" : "システム連絡先リスト",
     "The system address book contains contact information for all users in your instance." : "システムのアドレス帳には、インスタンスのすべてのユーザーの連絡先情報が含まれています。",
     "Enable System Address Book" : "システム連絡先リストを有効にする",
@@ -290,6 +292,25 @@ OC.L10N.register(
     "Pick a start time for {dayName}" : "{dayName} 開始時間を指定してください",
     "Pick a end time for {dayName}" : "{dayName} の終了時間を指定してください",
     "Automatically set user status to \"Do not disturb\" outside of availability to mute all notifications." : "利用時間外は自動的にユーザーステータスを\"非通知\" に設定し、すべての通知をミュートします。",
+    "Cancel" : "キャンセル",
+    "Import" : "インポート",
+    "Error while saving settings" : "設定の保存中にエラーが発生",
+    "Contact reset successfully" : "連絡先のリセットが正常に完了しました",
+    "Error while resetting contact" : "連絡先のリセット中にエラーが発生しました",
+    "Contact imported successfully" : "連絡先のインポートが正常に完了しました",
+    "Error while importing contact" : "連絡先のインポート中にエラーが発生しました",
+    "Import contact" : "連絡先のインポート",
+    "Reset to default" : "デフォルトに戻す",
+    "Import contacts" : "連絡先のインポート",
+    "Importing a new .vcf file will delete the existing default contact and replace it with the new one. Do you want to continue?" : "新しい .vcf ファイルをインポートすると、既存のデフォルト連絡先が削除され、新しいものに置き換えられます。続行しますか？",
+    "Failed to save example event creation setting" : "イベント作成例設定の保存に失敗しました",
+    "Failed to upload the example event" : "イベント例のアップロードに失敗しました",
+    "Custom example event was saved successfully" : "カスタムイベント例は正常に保存されました",
+    "Failed to delete the custom example event" : "カスタムイベント例の削除に失敗しました",
+    "Custom example event was deleted successfully" : "カスタムイベント例は正常に削除されました",
+    "Import calendar event" : "カレンダーイベントのインポート",
+    "Uploading a new event will overwrite the existing one." : "新しいイベントをアップロードすると既存のイベントは上書きされます。",
+    "Upload event" : "イベントをアップロード",
     "Availability" : "応対可能日時",
     "If you configure your working hours, other people will see when you are out of office when they book a meeting." : "勤務時間を設定すると、他のユーザが会議を予約する際に、あなたがいつ不在であるかがわかります。",
     "Absence" : "不在",
@@ -306,14 +327,12 @@ OC.L10N.register(
     "Send reminder notifications to calendar sharees as well" : "カレンダー共有にもリマインダー通知を送信する",
     "Reminders are always sent to organizers and attendees." : "リマインダーを常に作成者と出席者に送信します。",
     "Enable notifications for events via push" : "イベントのプッシュ通知を有効にする",
+    "Example content" : "コンテンツ例",
+    "Example content serves to showcase the features of Nextcloud. Default content is shipped with Nextcloud, and can be replaced by custom content." : "コンテンツ例はNextcloudの機能を紹介するものです。デフォルトのコンテンツはNextcloudに同梱されており、カスタムコンテンツで置き換えることができます。",
     "There was an error updating your attendance status." : "出席状況の更新中にエラーが発生しました。",
     "Please contact the organizer directly." : "主催者に直接お問い合わせください。",
     "Are you accepting the invitation?" : "招待を受け入れていますか？",
     "Tentative" : "暫定的",
-    "Your attendance was updated successfully." : "出席は正常に更新されました。",
-    "Time:" : "時刻:",
-    "Could not open file" : "ファイルを開くことができませんでした",
-    "Invalid chunk name" : "無効なチャンク名",
-    "Could not rename part file assembled from chunks" : "チャンクから構成されている部分ファイルの名前の変更ができませんでした"
+    "Your attendance was updated successfully." : "出席は正常に更新されました。"
 },
 "nplurals=1; plural=0;");
