@@ -250,6 +250,7 @@ OC.L10N.register(
     "Completed on %s" : "Slutförd %s",
     "Due on %s by %s" : "Slutar den %s vid %s",
     "Due on %s" : "Slutar den %s",
+    "Example event - open me!" : "Exempelhändelse – öppna mig!",
     "System Address Book" : "Systemadressbok",
     "The system address book contains contact information for all users in your instance." : "Systemadressboken innehåller kontaktinformation för alla användare i din instans.",
     "Enable System Address Book" : "Aktivera systemadressboken",
@@ -290,6 +291,25 @@ OC.L10N.register(
     "Pick a start time for {dayName}" : "Välj en starttid för {dayName}",
     "Pick a end time for {dayName}" : "Välj en sluttid för {dayName}",
     "Automatically set user status to \"Do not disturb\" outside of availability to mute all notifications." : "Sätt automatiskt användarstatus till \"Stör ej\" utanför tillgängliga tider för att tysta alla notifikationer.",
+    "Cancel" : "Avbryt",
+    "Import" : "Importera",
+    "Error while saving settings" : "Fel vid sparande av inställningar",
+    "Contact reset successfully" : "Kontakten har återställts",
+    "Error while resetting contact" : "Fel vid återställning av kontakt",
+    "Contact imported successfully" : "Kontakten har importerats",
+    "Error while importing contact" : "Fel vid import av kontakt",
+    "Import contact" : "Importera kontakt",
+    "Reset to default" : "Återställ till grundinställningar",
+    "Import contacts" : "Importera kontakter",
+    "Importing a new .vcf file will delete the existing default contact and replace it with the new one. Do you want to continue?" : "Att importera en ny .vcf-fil kommer att radera den befintliga standardkontakten och ersätta den med den nya. Vill du fortsätta?",
+    "Failed to save example event creation setting" : "Kunde inte spara exemplet för inställning av händelseskapande",
+    "Failed to upload the example event" : "Kunde inte ladda upp exempelhändelsen",
+    "Custom example event was saved successfully" : "Anpassad exempelhändelse sparades",
+    "Failed to delete the custom example event" : "Kunde inte ta bort den anpassade exempelhändelsen",
+    "Custom example event was deleted successfully" : "Anpassad exempelhändelse har raderats",
+    "Import calendar event" : "Importera kalenderhändelse",
+    "Uploading a new event will overwrite the existing one." : "Om du laddar upp en ny händelse kommer den att skriva över den befintliga.",
+    "Upload event" : "Ladda upp händelse",
     "Availability" : "Din tillgänglighet",
     "If you configure your working hours, other people will see when you are out of office when they book a meeting." : "Om du konfigurerar dina arbetstider kommer andra att se när du är frånvarande när de bokar ett möte.",
     "Absence" : "Frånvaro",
@@ -306,27 +326,12 @@ OC.L10N.register(
     "Send reminder notifications to calendar sharees as well" : "Skicka även påminnelser till kalenderdeltagare",
     "Reminders are always sent to organizers and attendees." : "Påminnelser skickas alltid till arrangörer och deltagare.",
     "Enable notifications for events via push" : "Aktivera notiser för händelser via push",
-    "Cancel" : "Avbryt",
-    "Import" : "Importera",
-    "Error while saving settings" : "Fel vid sparande av inställningar",
-    "Contact reset successfully" : "Kontakten har återställts",
-    "Error while resetting contact" : "Fel vid återställning av kontakt",
-    "Contact imported successfully" : "Kontakten har importerats",
-    "Error while importing contact" : "Fel vid import av kontakt",
-    "Example Content" : "Exempelinnehåll",
-    "Set example content to be created on new user first login." : "Ställ in exempelinnehåll som ska skapas vid ny användares första inloggning.",
-    "Import contact" : "Importera kontakt",
-    "Reset to default contact" : "Återställ till standardkontakt",
-    "Import contacts" : "Importera kontakter",
-    "Importing a new .vcf file will delete the existing default contact and replace it with the new one. Do you want to continue?" : "Att importera en ny .vcf-fil kommer att radera den befintliga standardkontakten och ersätta den med den nya. Vill du fortsätta?",
+    "Example content" : "Exempelinnehåll",
+    "Example content serves to showcase the features of Nextcloud. Default content is shipped with Nextcloud, and can be replaced by custom content." : "Exempelinnehåll används för att visa upp funktionerna i Nextcloud. Standardinnehåll levereras med Nextcloud och kan ersättas med anpassat innehåll.",
     "There was an error updating your attendance status." : "Ett fel uppstod vid uppdatering av din närvarostatus.",
     "Please contact the organizer directly." : "Vänligen kontakta arrangören direkt.",
     "Are you accepting the invitation?" : "Acceptera inbjudan?",
     "Tentative" : "Preliminärt",
-    "Your attendance was updated successfully." : "Dina närvaro uppdaterades.",
-    "Time:" : "Tid:",
-    "Could not open file" : "Kunde inte öppna fil",
-    "Invalid chunk name" : "Ogiltigt delnamn",
-    "Could not rename part file assembled from chunks" : "Kunde inte ändra namn på temporära filen ihopsatt från delar"
+    "Your attendance was updated successfully." : "Dina närvaro uppdaterades."
 },
 "nplurals=2; plural=(n != 1);");
