@@ -46,20 +46,21 @@ OC.L10N.register(
     "Automatically accept shares from trusted federated accounts and groups by default" : "Freigaben von vertrauenswürdigen Federation-Konten und -gruppen standardmäßig automatisch akzeptieren",
     "Share with me through my #Nextcloud Federated Cloud ID, see {url}" : "Teilen Sie mit mir über meine #Nextcloud Federated-Cloud-ID, siehe {url}",
     "Share with me through my #Nextcloud Federated Cloud ID" : "Teilen Sie mit mir über meine #Nextcloud Federated-Cloud-ID",
-    "Cloud ID copied to the clipboard" : "Cloud-ID wurde in die Zwischenablage kopiert",
-    "Copy to clipboard" : "In die Zwischenablage kopieren",
+    "Share with me via Nextcloud" : "Teilen Sie mit mir über Nextcloud",
+    "Cloud ID copied" : "Cloud-ID kopiert",
+    "Copy" : "Kopieren",
     "Clipboard not available. Please copy the cloud ID manually." : "Zwischenablage nicht verfügbar. Bitte die Cloud-ID manuell kopieren.",
     "Copied!" : "Kopiert!",
     "Federated Cloud" : "Federated Cloud",
     "You can share with anyone who uses a Nextcloud server or other Open Cloud Mesh (OCM) compatible servers and services! Just put their Federated Cloud ID in the share dialog. It looks like person@cloud.example.com" : "Sie können mit jedem teilen, der einen Nextcloud-Server oder andere Open Cloud Mesh (OCM) kompatible Server und Dienste verwendet! Geben Sie einfach deren Federated-Cloud-ID in den Teilen-Dialog ein. Diese sieht wie folgt aus: person@cloud.example.com",
     "Your Federated Cloud ID" : "Ihre Federated-Cloud-ID",
-    "Share it so your friends can share files with you:" : "Teilen Sie es, so dass Ihre Freunde Dateien mit Ihnen teilen können:",
+    "Share it so your friends can share files with you:" : "Teilen Sie es, damit Ihre Freunde Dateien mit Ihnen teilen können:",
     "Facebook" : "Facebook",
     "X (formerly Twitter)" : "X (früher Twitter)",
     "formerly Twitter" : "früher Twitter",
     "Mastodon" : "Mastodon",
+    "Bluesky" : "Bluesky",
     "Add to your website" : "Zu Ihrer Webseite hinzufügen",
-    "Share with me via Nextcloud" : "Teilen Sie mit mir über Nextcloud",
     "HTML Code:" : "HTML-Code:",
     "Cancel" : "Abbrechen",
     "Add remote share" : "Externe Freigabe hinzufügen",
@@ -67,9 +68,7 @@ OC.L10N.register(
     "Do you want to add the remote share {name} from {owner}@{remote}?" : "Möchten Sie die externe Freigabe {name} von {owner}@{remote} hinzufügen?",
     "Remote share password" : "Passwort für die externe Freigabe",
     "Incoming share could not be processed" : "Eingehende Freigabe konnte nicht verarbeitet werden",
-    "Clipboard is not available" : "Zwischenablage ist nicht verfügbar",
-    "Your Federated Cloud ID:" : "Ihre Federated-Cloud-ID:",
-    "Twitter" : "Twitter",
-    "Diaspora" : "Diaspora"
+    "Cloud ID copied to the clipboard" : "Cloud-ID wurde in die Zwischenablage kopiert",
+    "Copy to clipboard" : "In die Zwischenablage kopieren"
 },
 "nplurals=2; plural=(n != 1);");
