@@ -51,7 +51,6 @@ OC.L10N.register(
     "Favorite files" : "Gogoko fitxategiak",
     "No favorites" : "Gogokorik ez",
     "More favorites" : "Gogoko gehiago",
-    "Upload (max. %s)" : "Igo (%s gehienez)",
     "Accept" : "Onartu",
     "Reject" : "Ukatu",
     "Incoming ownership transfer from {user}" : "{user}(r)en jabetza-transferentzia",
@@ -91,10 +90,12 @@ OC.L10N.register(
     "Invalid filename." : "Fitxategi-izen baliogabea.",
     "Renamed \"{oldName}\" to \"{newName}\"" : "\"{oldName}\" \"{newName}\"(e)ra berrizendatu da.",
     "Rename file" : "Berrizendatu fitxategia",
+    "Folder" : "Karpeta",
     "Pending" : "Zain",
     "Unknown date" : "Data ezezaguna",
     "Clear filter" : "Garbitu iragazkia",
     "Modified" : "Aldatuta",
+    "Search everywhere" : "Bilatu nonahi",
     "Type" : "Mota",
     "Active filters" : "Iragazki aktiboak",
     "Remove filter" : "Kendu iragazkia",
@@ -102,8 +103,6 @@ OC.L10N.register(
     "Toggle selection for all files and folders" : "Ordeztu hautatutako fitxategi eta karpeta guztiak",
     "Name" : "Izena",
     "Size" : "Tamaina",
-    "\"{displayName}\" batch action executed successfully" : "\"{displayName}\" multzoko ekintza behar bezala exekutatu da",
-    "\"{displayName}\" action failed" : "\"{displayName}\" ekintzak huts egin du",
     "Actions" : "Ekintzak",
     "(selected)" : "(hautatuta)",
     "List of files and folders." : "Fitxategi eta karpeten zerrenda.",
@@ -111,7 +110,7 @@ OC.L10N.register(
     "Column headers with buttons are sortable." : "Botoiak dituzten zutabeen goiburuak ordena daitezke.",
     "This list is not fully rendered for performance reasons. The files will be rendered as you navigate through the list." : "Zerrenda hau ez da guztiz ikusten errendimendu arrazoiengatik. Fitxategiak zerrendan zehar nabigatzen duten heinean bistaratuko dira.",
     "File not found" : "Ez da fitxategia aurkitu",
-    "{count} selected" : "{count} hautatuta",
+    "_{count} selected_::_{count} selected_" : ["{count} hautatuta","{count} hautatuta"],
     "{usedQuotaByte} used" : "{usedQuotaByte} erabilita",
     "{used} of {quota} used" : "{used} / {quota} erabilita",
     "{relative}% used" : "%{relative} erabilita",
@@ -155,7 +154,6 @@ OC.L10N.register(
     "Error during upload: {message}" : "Errorea igotzean: {message}",
     "Error during upload, status code {status}" : "Errore bat gertatu da igotzean, {status} egoera kodea",
     "Unknown error during upload" : "Errore ezezaguna igotzean",
-    "\"{displayName}\" action executed successfully" : "\"{displayName}\" ekintza behar bezala exekutatu da",
     "Loading current folder" : "Uneko karpeta kargatzen",
     "Retry" : "saiatu berriro",
     "No files in here" : "Ez dago fitxategirik hemen",
@@ -168,40 +166,29 @@ OC.L10N.register(
     "File cannot be accessed" : "Ezin da fitxategia atzitu",
     "The file could not be found or you do not have permissions to view it. Ask the sender to share it." : "Ezin izan da fitxategia aurkitu edo ez duzu ikusteko baimenik. Eskatu bidaltzaileari partekatzeko.",
     "Clipboard is not available" : "Arbela ez dago erabilgarri",
-    "WebDAV URL copied to clipboard" : "WebDAV URLa arbelean kopiatu da",
+    "General" : "Orokorra",
+    "All files" : "Fitxategi guztiak",
+    "Personal files" : "Fitxategi pertsonalak",
     "Sort favorites first" : "Ordenatu gogokoak lehenengo",
     "Sort folders before files" : "Ordenatu karpetak fitxategien aurretik",
+    "Appearance" : "Itxura",
     "Show hidden files" : "Erakutsi ezkutuko fitxategiak",
     "Crop image previews" : "Moztu irudien aurrebistak",
-    "Enable the grid view" : "Gaitu sareta ikuspegira",
-    "Enable folder tree" : "Gaitu karpeta-zuhaitza",
     "Additional settings" : "Ezarpen gehiago",
     "WebDAV" : "WebDAV",
     "WebDAV URL" : "WebDAV URLa",
-    "Copy to clipboard" : "Kopiatu arbelera",
-    "Use this address to access your Files via WebDAV" : "Erabili helbide hau WebDAV bidez zure fitxategietara sartzeko",
-    "If you have enabled 2FA, you must create and use a new app password by clicking here." : "2FA gaitu baduzu, aplikazioaren pasahitz berria sortu eta erabili behar duzu hemen klik eginez.",
+    "Copy" : "Kopiatu",
     "Keyboard shortcuts" : "Teklatuaren lasterbideak",
-    "Speed up your Files experience with these quick shortcuts." : "Azkartu zure Fitxategi esperientzia lasterbide bizkor hauekin",
-    "Open the actions menu for a file" : "Ireki ekintza menua fitxategi baterako",
-    "Rename a file" : "Fitxategi bat berrizendatu",
-    "Delete a file" : "Fitxategi bat ezabatu",
-    "Favorite or remove a file from favorites" : "Fitxategi bat gustoko bihurtu edo gustoko izateari utzi",
-    "Manage tags for a file" : "Fitxategi baten etiketak kudeatu",
+    "File actions" : "Fitxategi ekintzak",
+    "Rename" : "Berrizendatu",
+    "Delete" : "Ezabatu",
+    "Manage tags" : "Kudeatu etiketak",
     "Selection" : "Hautapena",
     "Select all files" : "Fitxategi guztiak aukeratu",
-    "Deselect all files" : "Fitxategi guztiak desaukeratu",
-    "Select or deselect a file" : "Fitxategi bat aukeratu edo desaukeratu",
-    "Select a range of files" : "Fitxategi-hein bat aukeratu",
+    "Deselect all" : "Deshautatu dena",
     "Navigation" : "Nabigazioa",
-    "Navigate to the parent folder" : "Nabigatu guraso karpetara",
-    "Navigate to the file above" : "Nabigatu goiko fitxategira",
-    "Navigate to the file below" : "Nabigatu azpiko fitxategira",
-    "Navigate to the file on the left (in grid mode)" : "Nabigatu ezkerreko fitxategira (sareta moduan)",
-    "Navigate to the file on the right (in grid mode)" : "Nabigatu eskuineko fitxategira (sareta moduan)",
     "View" : "Ikusi",
-    "Toggle the grid view" : "Txandakatu sareta ikuspegia",
-    "Open the sidebar for a file" : "Ireki alboko barra fitxategi baterako",
+    "Toggle grid view" : "Txandakatu sareta ikuspegia",
     "Show those shortcuts" : "Erakutsi lasterbide horiek",
     "You" : "Zu ",
     "Shared multiple times with different people" : "Hainbat aldiz partekatua pertsona ezberdinekin",
@@ -215,7 +202,6 @@ OC.L10N.register(
     "Pick a template for {name}" : "Hautatu {name}(r)entzako txantiloia",
     "Create a new file with the selected template" : "Sortu fitxategi berria hautatutako txantiloiarekin",
     "Creating file" : "Fitxategia sortzen",
-    "Deletion cancelled" : "Ezabatzea bertan behera utzi da",
     "Leave this share" : "Utzi partekatze hau",
     "Leave these shares" : "Utzi partekatze hauek",
     "Disconnect storage" : "Deskonektatu biltegia",
@@ -226,38 +212,35 @@ OC.L10N.register(
     "Delete files" : "Ezabatu fitxategiak",
     "Delete folder" : "Ezabatu karpeta",
     "Delete folders" : "Ezabatu karpetak",
-    "Delete" : "Ezabatu",
     "_You are about to permanently delete {count} item_::_You are about to permanently delete {count} items_" : ["Elementu {count} betiko ezabatzera zoaz","{count} elementu betiko ezabatzera zoaz"],
     "_You are about to delete {count} item_::_You are about to delete {count} items_" : ["Elementu {count} ezabatzera zoaz"," {count}  elementu ezabatzera zoaz"],
     "Confirm deletion" : "Berretsi ezabaketa",
     "Cancel" : "Utzi",
+    "Download" : "Deskargatu",
     "Moving \"{source}\" to \"{destination}\" …" : "«{source}» «{destination}»(e)ra mugitzen",
     "Copying \"{source}\" to \"{destination}\" …" : "«{source}» «{destination}»(e)ra mugitzen",
+    "Destination is not a folder" : "Helburua ez da karpeta bat",
+    "This file/folder is already in that directory" : "Fitxategi/karpeta hau dagoeneko karpeta horretan dago",
     "You cannot move a file/folder onto itself or into a subfolder of itself" : "Ezin duzu fitxategi/karpeta bat berera edo bere azpikarpeta batera mugitu",
     "(copy)" : "(kopiatu)",
     "(copy %n)" : "(kopiatu %n)",
-    "Move cancelled" : "Mugimendua bertan behera utzi da",
     "A file or folder with that name already exists in this folder" : "Izen hori duen fitxategi edo karpeta bat dago karpena honetan",
     "The files are locked" : "Fitxategiak blokeatuta daude",
     "The file does not exist anymore" : "Fitxategia ez da existizen dagoeneko",
     "Choose destination" : "Aukeratu helburua",
     "Copy to {target}" : "Kopiatu hona: {target}",
-    "Copy" : "Kopiatu",
     "Move to {target}" : "Mugitu hona: {target}",
     "Move" : "Mugitu",
     "Move or copy operation failed" : "Mugitzeko edo kopiatzeko eragiketak huts egin du",
     "Move or copy" : "Mugitu edo kopiatu",
-    "Cancelled move or copy of \"{filename}\"." : "\"{filename}\" -ren mugimendua edo kopia bertan behera utzi da.",
-    "Cancelled move or copy operation" : "Mugitze edo kopiatze operazioa utzi da",
     "Open folder {displayName}" : "Ireki {displayName} karpeta",
     "Open in Files" : "Ireki Fitxategiak aplikazioan",
+    "Open locally" : "Ireki lokalean",
+    "Failed to redirect to client" : "Bezerora birbideratzeak huts egin du",
     "Open file locally" : "Ireki fitxategia lokalean",
     "The file should now open on your device. If it doesn't, please check that you have the desktop app installed." : "Fitxategia orain zure gailuan ireki beharko litzateke. Hala ez bada, egiaztatu mahaigaineko aplikazioa instalatuta duzula.",
     "Retry and close" : "Saiatu berriro eta itxi",
-    "Failed to redirect to client" : "Bezerora birbideratzeak huts egin du",
-    "Open locally" : "Ireki lokalean",
-    "Rename" : "Berrizendatu",
-    "Open details" : "Ireki xehetasunak",
+    "Details" : "Xehetasunak",
     "View in folder" : "Ikusi karpetan",
     "Today" : "Gaur",
     "Last 7 days" : "Azken 7 egunetan",
@@ -270,9 +253,8 @@ OC.L10N.register(
     "PDFs" : "PDFak",
     "Folders" : "Karpetak",
     "Audio" : "Audio",
-    "Photos and images" : "Argazkiak eta irudiak",
+    "Images" : "Irudiak",
     "Videos" : "Bideoak",
-    "New folder creation cancelled" : "Karpeta berrien sorrera bertan behera utzi da",
     "Created new folder \"{name}\"" : "\"{name}\" karpeta berria sortu da",
     "Unable to initialize the templates directory" : "Ezin da txantiloien direktorioa hasieratu",
     "Create templates folder" : "Sortu txantiloien karpeta",
@@ -293,15 +275,14 @@ OC.L10N.register(
     "Files moved successfully" : "Fitxategiak behar bezala mugitu dira",
     "Conflicts resolution skipped" : "Gatazkak konpontzea saihestu da",
     "Upload cancelled" : "Igotzea bertan behera utzi da",
+    "Could not rename \"{oldName}\", it does not exist any more" : "Ezin izan da \"{oldName}\" berrizendatu, ez da existitzen dagoeneko",
+    "The name \"{newName}\" is already used in the folder \"{dir}\". Please choose a different name." : "\"{newName}\" izena \"{dir}\" karpetan dagoeneko erabiltzen da. Mesedez aukeratu beste izen bat.",
+    "Could not rename \"{oldName}\"" : "Ezin izan da \"{oldName}\" berrizendatu ",
     "This operation is forbidden" : "Eragiketa hau debekatuta dago",
-    "This directory is unavailable, please check the logs or contact the administrator" : "Direktorio hau ez dago erabilgarri, egiaztatu egunkariak edo jarri administratzailearekin harremanetan",
     "Storage is temporarily not available" : "Biltegia ez dago erabilgarri aldi baterako",
     "Unexpected error: {error}" : "Ustekabeko errorea: {error}",
-    "_{folderCount} folder_::_{folderCount} folders_" : ["Karpeta {folderCount}","{folderCount} karpeta"],
-    "_{fileCount} file_::_{fileCount} files_" : ["Fitxategi {fileCount}","{fileCount} fitxategi"],
-    "_1 file and {folderCount} folder_::_1 file and {folderCount} folders_" : ["Fitxategi 1 eta karpeta {folderCount}","Fitxategi 1 eta {folderCount} karpeta"],
-    "_{fileCount} file and 1 folder_::_{fileCount} files and 1 folder_" : ["Fitxategi {fileCount} eta karpeta 1","{fileCount} fitxategi eta karpeta 1"],
-    "{fileCount} files and {folderCount} folders" : "{fileCount} fitxategi eta {folderCount} fitxategi",
+    "_%n file_::_%n files_" : ["Fitxategi %n","%n fitxategi"],
+    "_%n folder_::_%n folders_" : ["Karpeta %n","%n karpeta"],
     "Filename must not be empty." : "Fitxategi-izenak ez du hutsik egon behar.",
     "\"{char}\" is not allowed inside a filename." : "\"{char}\" ez da onartzen fitxategi-izen baten barruan.",
     "\"{segment}\" is a reserved name and not allowed for filenames." : "\"{segment}\" izen erreserbatua da eta ez da onartzen fitxategi-izenetan.",
@@ -310,10 +291,7 @@ OC.L10N.register(
     "List of favorite files and folders." : "Gogoko fitxategi eta karpeten zerrenda.",
     "No favorites yet" : "Gogokorik ez oraindik",
     "Files and folders you mark as favorite will show up here" : "Gogokotzat markatutako fitxategi eta karpetak hemen agertuko dira",
-    "All files" : "Fitxategi guztiak",
     "List of your files and folders." : "Zure fitxategi eta karpeten zerrenda.",
-    "All folders" : "Karpeta guztiak",
-    "Personal files" : "Fitxategi pertsonalak",
     "List of your files and folders that are not shared." : "Partekatu ez diren zure fitxategi eta karpeten zerrenda.",
     "No personal files found" : "Ez dago fitxategi pertsonalik",
     "Files that are not shared will show up here." : "Partekatu ez dituzun fitxategiak hemen agertuko dira",
@@ -321,12 +299,12 @@ OC.L10N.register(
     "List of recently modified files and folders." : "Azkenaldian aldatutako fitxategi eta karpeten zerrenda.",
     "No recently modified files" : "Ez dago azkenaldian aldatutako fitxategirik",
     "Files and folders you recently modified will show up here." : "Azkenaldian aldatu dituzun fitxategi eta karpetak hemen agertuko dira.",
+    "Search" : "Bilatu",
     "No entries found in this folder" : "Ez da sarrerarik aurkitu karpeta honetan",
     "Select all" : "Hautatu dena",
     "Upload too large" : "Igotzekoa handiegia da",
     "The files you are trying to upload exceed the maximum size for file uploads on this server." : "Igotzen saiatzen ari zaren fitxategiek zerbitzari honek onartzen duen gehienezko tamaina gainditzen dute.",
     "File could not be found" : "Ezin izan da fitxategia aurkitu",
-    "Download" : "Deskargatu",
     "Show list view" : "Erakutsi zerrenda ikuspegia",
     "Show grid view" : "Erakutsi sareta ikuspegia",
     "Close" : "Itxi",
@@ -351,12 +329,12 @@ OC.L10N.register(
     "Edit locally" : "Editatu lokalean",
     "Open" : "Ireki",
     "Could not load info for file \"{file}\"" : "Ezin izan da \"{file}\" fitxategiaren informazioa kargatu",
-    "Details" : "Xehetasunak",
     "Please select tag(s) to add to the selection" : "Hautatu etiketa(k) hautapenera gehitzeko",
     "Apply tag(s) to selection" : "Aplikatu etiketa(k) hautapenari",
     "Select directory \"{dirName}\"" : "Hautatu \"{dirName}\" direktorioa",
     "Select file \"{fileName}\"" : "Hautatu \"{fileName}\" fitxategia",
     "Unable to determine date" : "Ezin izan da data zehaztu",
+    "This directory is unavailable, please check the logs or contact the administrator" : "Direktorio hau ez dago erabilgarri, egiaztatu egunkariak edo jarri administratzailearekin harremanetan",
     "Could not move \"{file}\", target exists" : "Ezin izan da \"{file}\" lekuz aldatu, helburua existitzen da jadanik",
     "Could not move \"{file}\"" : "Ezin izan da \"{file}\" lekuz aldatu",
     "copy" : "kopiatu",
@@ -365,9 +343,6 @@ OC.L10N.register(
     "Copied {origin} inside {destination}" : "{origin} kopiatu da {destination} barruan",
     "Copied {origin} and {nbfiles} other files inside {destination}" : "{origin} eta beste {nbfiles} fitxategi {destination} barruan kopiatu dira",
     "{newName} already exists" : "{newName} existitzen da dagoeneko",
-    "Could not rename \"{fileName}\", it does not exist any more" : "Ezin izan da \"{fileName}\" berrizendatu, ez da existitzen jada",
-    "The name \"{targetName}\" is already used in the folder \"{dir}\". Please choose a different name." : "\"{targetName}\" izena dagoeneko erabiltzen da \"{dir}\" karpetan. Aukeratu beste izen bat.",
-    "Could not rename \"{fileName}\"" : "Ezin izan da \"{fileName}\" berrizendatu ",
     "Could not create file \"{file}\"" : "Ezin izan da \"{file}\" fitxategia sortu",
     "Could not create file \"{file}\" because it already exists" : "Ezin izan da \"{file}\" fitxategia sortu, dagoeneko existitzen delako",
     "Could not create folder \"{dir}\" because it already exists" : "Ezin izan da \"{dir}\" karpeta sortu, dagoeneko existitzen delako",
@@ -375,8 +350,6 @@ OC.L10N.register(
     "Error deleting file \"{fileName}\"." : "Errorea \"{fileName}\" fitxategia ezabatzerakoan.",
     "No search results in other folders for {tag}{filter}{endtag}" : "Ez da '{tag}{filter}{endtag}' bilaketarako emaitzarik aurkitu beste karpetetan",
     "Enter more than two characters to search in other folders" : "Sartu bi karaktere baino gehiago beste karpetetan bilatu ahal izateko",
-    "_%n folder_::_%n folders_" : ["Karpeta %n","%n karpeta"],
-    "_%n file_::_%n files_" : ["Fitxategi %n","%n fitxategi"],
     "{dirs} and {files}" : "{dirs} eta {files}",
     "_including %n hidden_::_including %n hidden_" : ["ezkutuko %n barne","ezkutuko %n barne"],
     "You do not have permission to upload or create files here" : "Ez duzu hemen fitxategiak igotzeko edo sortzeko baimenik",
@@ -402,27 +375,55 @@ OC.L10N.register(
     "Direct link was copied (only works for people who have access to this file/folder)" : "Esteka zuzena kopiatu da (fitxategi/karpeta honetara sarbidea dutenentzat bakarrik balio du)",
     "Path" : "Bidea",
     "_%n byte_::_%n bytes_" : ["%n byte","%n byte"],
-    "Favorited" : "Gogoko gisa markatua",
+    "Favored" : "Mesedetua",
+    "Favor" : "Mesedea",
     "Copy direct link (only works for people who have access to this file/folder)" : "Kopiatu esteka zuzena (fitxategi/karpeta honetara sarbidea dutenentzat bakarrik balio du)",
     "Upload file" : "Igo fitxategia",
-    "Not favorited" : "Ez da gogokoa",
+    "Not favored" : "Mesedetu gabe",
     "An error occurred while trying to update the tags" : "Errore bat gertatu da etiketak eguneratzen saiatzean",
-    "Storage informations" : "Biltegiaren informazioak",
-    "Choose file" : "Aukeratu fitxategia",
-    "Go to the previous folder" : "Joan aurreko karpetara",
-    "Open the files app settings" : "Ireki Fitxategiak aplikazioaren ezarpenak",
-    "Unable to change the favourite state of the file" : "Ezin da fitxategiaren gogoko egoera aldatu",
-    "Edit file locally" : "Editatu fitxategia lokalean",
-    "Edit online" : "Editatu sarean",
-    "Create new templates folder" : "Sortu txantiloi karpeta berria",
-    "List of favorites files and folders." : "Fitxategi eta karpeta gogokoen zerrenda.",
+    "Upload (max. %s)" : "Igo (%s gehienez)",
+    "\"{displayName}\" action executed successfully" : "\"{displayName}\" ekintza behar bezala exekutatu da",
+    "\"{displayName}\" action failed" : "\"{displayName}\" ekintzak huts egin du",
+    "\"{displayName}\" batch action executed successfully" : "\"{displayName}\" multzoko ekintza behar bezala exekutatu da",
+    "Submitting fields…" : "Eremuak bidaltzen…",
+    "Filter filenames…" : "Iragazi fitxategi-izenak...",
+    "WebDAV URL copied to clipboard" : "WebDAV URLa arbelean kopiatu da",
+    "Enable the grid view" : "Gaitu sareta ikuspegira",
+    "Enable folder tree" : "Gaitu karpeta-zuhaitza",
+    "Copy to clipboard" : "Kopiatu arbelera",
+    "Use this address to access your Files via WebDAV" : "Erabili helbide hau WebDAV bidez zure fitxategietara sartzeko",
+    "If you have enabled 2FA, you must create and use a new app password by clicking here." : "2FA gaitu baduzu, aplikazioaren pasahitz berria sortu eta erabili behar duzu hemen klik eginez.",
+    "Deletion cancelled" : "Ezabatzea bertan behera utzi da",
+    "Move cancelled" : "Mugimendua bertan behera utzi da",
+    "Cancelled move or copy of \"{filename}\"." : "\"{filename}\" -ren mugimendua edo kopia bertan behera utzi da.",
+    "Cancelled move or copy operation" : "Mugitze edo kopiatze operazioa utzi da",
+    "Open details" : "Ireki xehetasunak",
+    "Photos and images" : "Argazkiak eta irudiak",
+    "New folder creation cancelled" : "Karpeta berrien sorrera bertan behera utzi da",
+    "_{folderCount} folder_::_{folderCount} folders_" : ["Karpeta {folderCount}","{folderCount} karpeta"],
+    "_{fileCount} file_::_{fileCount} files_" : ["Fitxategi {fileCount}","{fileCount} fitxategi"],
+    "_1 file and {folderCount} folder_::_1 file and {folderCount} folders_" : ["Fitxategi 1 eta karpeta {folderCount}","Fitxategi 1 eta {folderCount} karpeta"],
+    "_{fileCount} file and 1 folder_::_{fileCount} files and 1 folder_" : ["Fitxategi {fileCount} eta karpeta 1","{fileCount} fitxategi eta karpeta 1"],
+    "{fileCount} files and {folderCount} folders" : "{fileCount} fitxategi eta {folderCount} fitxategi",
+    "All folders" : "Karpeta guztiak",
     "Personal Files" : "Fitxategi pertsonalak",
     "Text file" : "Testu-fitxategia",
     "New text file.txt" : "Testu-fitxategi berria.txt",
-    "Favored" : "Mesedetua",
-    "Favor" : "Mesedea",
-    "Not favored" : "Mesedetu gabe",
-    "Submitting fields…" : "Eremuak bidaltzen…",
-    "Filter filenames…" : "Iragazi fitxategi-izenak..."
+    "Speed up your Files experience with these quick shortcuts." : "Azkartu zure Fitxategi esperientzia lasterbide bizkor hauekin",
+    "Open the actions menu for a file" : "Ireki ekintza menua fitxategi baterako",
+    "Rename a file" : "Fitxategi bat berrizendatu",
+    "Delete a file" : "Fitxategi bat ezabatu",
+    "Favorite or remove a file from favorites" : "Fitxategi bat gustoko bihurtu edo gustoko izateari utzi",
+    "Manage tags for a file" : "Fitxategi baten etiketak kudeatu",
+    "Deselect all files" : "Fitxategi guztiak desaukeratu",
+    "Select or deselect a file" : "Fitxategi bat aukeratu edo desaukeratu",
+    "Select a range of files" : "Fitxategi-hein bat aukeratu",
+    "Navigate to the parent folder" : "Nabigatu guraso karpetara",
+    "Navigate to the file above" : "Nabigatu goiko fitxategira",
+    "Navigate to the file below" : "Nabigatu azpiko fitxategira",
+    "Navigate to the file on the left (in grid mode)" : "Nabigatu ezkerreko fitxategira (sareta moduan)",
+    "Navigate to the file on the right (in grid mode)" : "Nabigatu eskuineko fitxategira (sareta moduan)",
+    "Toggle the grid view" : "Txandakatu sareta ikuspegia",
+    "Open the sidebar for a file" : "Ireki alboko barra fitxategi baterako"
 },
 "nplurals=2; plural=(n != 1);");
