@@ -13,6 +13,7 @@ OC.L10N.register(
     "Restored by {user}" : "بازیابی شده توسط {user}",
     "Renamed by {user}" : "تغییر نام توسط {user}",
     "Moved by {user}" : "منتقل شده توسط {user}",
+    "\"remote account\"" : "&quot;حساب از راه دور&quot;",
     "You created {file}" : "شما {file} را ایجاد کردید",
     "You created an encrypted file in {file}" : "شما یک فایل رمزگذاری شده در {file} ایجاد کردید",
     "{user} created {file}" : "{user} {file} را ایجاد کرد",
@@ -42,12 +43,23 @@ OC.L10N.register(
     "Files" : "پرونده‌ها",
     "A file or folder has been <strong>changed</strong>" : "یک فایل یا پوشه تغییر کرده است",
     "A favorite file or folder has been <strong>changed</strong>" : "یک فایل یا پوشه مورد علاقه تغییر کرده است",
+    "Failed to authorize" : "مجوز صادر نشد",
+    "Invalid folder path" : "Invalid folder path",
+    "Folder not found" : "Folder not found",
+    "The file cannot be found" : "The file cannot be found",
+    "The destination path does not exist: %1$s" : "The destination path does not exist: %1$s",
+    "You do not have permission to create a file at the specified location" : "You do not have permission to create a file at the specified location",
+    "The file could not be converted." : "The file could not be converted.",
+    "Could not get relative path to converted file" : "Could not get relative path to converted file",
+    "Favorite files" : "Favorite files",
     "No favorites" : "هیچ برگزیده",
-    "Upload (max. %s)" : "آپلود (بیشترین سایز %s)",
+    "More favorites" : "More favorites",
     "Accept" : "قبول",
     "Reject" : "رد کردن",
     "Incoming ownership transfer from {user}" : "انتقال مالکیت ورودی از {user}",
     "Do you want to accept {path}?\n\nNote: The transfer process after accepting may take up to 1 hour." : "آیا می خواهید {path} را بپذیرید؟\n\nتوجه: فرآیند انتقال پس از پذیرش ممکن است تا 1 ساعت طول بکشد.",
+    "Ownership transfer denied" : "Ownership transfer denied",
+    "Your ownership transfer of {path} was denied by {user}." : "Your ownership transfer of {path} was denied by {user}.",
     "Ownership transfer failed" : "انتقال مالکیت ناموفق بود",
     "Your ownership transfer of {path} to {user} failed." : "انتقال مالکیت شما از {path} به {user} انجام نشد.",
     "The ownership transfer of {path} from {user} failed." : "انتقال مالکیت {path} از {user} انجام نشد.",
@@ -55,41 +67,74 @@ OC.L10N.register(
     "Your ownership transfer of {path} to {user} has completed." : "انتقال مالکیت شما از {path} به {user} تکمیل شد.",
     "The ownership transfer of {path} from {user} has completed." : "انتقال مالکیت {path} از {user} تکمیل شد.",
     "in %s" : "در %s",
+    "Transferred from %1$s on %2$s" : "Transferred from %1$s on %2$s",
+    "Files compatibility" : "Files compatibility",
+    "Allow to restrict filenames to ensure files can be synced with all clients. By default all filenames valid on POSIX (e.g. Linux or macOS) are allowed." : "Allow to restrict filenames to ensure files can be synced with all clients. By default all filenames valid on POSIX (e.g. Linux or macOS) are allowed.",
+    "After enabling the Windows compatible filenames, existing files cannot be modified anymore but can be renamed to valid new names by their owner." : "After enabling the Windows compatible filenames, existing files cannot be modified anymore but can be renamed to valid new names by their owner.",
+    "It is also possible to migrate files automatically after enabling this setting, please refer to the documentation about the occ command." : "It is also possible to migrate files automatically after enabling this setting, please refer to the documentation about the occ command.",
+    "Enforce Windows compatibility" : "Enforce Windows compatibility",
+    "This will block filenames not valid on Windows systems, like using reserved names or special characters. But this will not enforce compatibility of case sensitivity." : "This will block filenames not valid on Windows systems, like using reserved names or special characters. But this will not enforce compatibility of case sensitivity.",
     "File Management" : "مدیریت فایل",
     "Home" : "خانه",
     "Target folder does not exist any more" : "پوشه هدف وجود ندارد",
     "Reload current directory" : "دایرکتوری فعلی را دوباره بارگیری کنید",
     "Go to the \"{dir}\" directory" : "به دایرکتوری \"{dir}\" بروید",
+    "Current directory path" : "Current directory path",
+    "Your have used your space quota and cannot upload files anymore" : "Your have used your space quota and cannot upload files anymore",
+    "You do not have permission to upload or create files here." : "You do not have permission to upload or create files here.",
     "Drag and drop files here to upload" : "برای بارگذاری، فایل‌ها را بکشید و اینجا بیاندازید",
     "Favorite" : "برگزیده",
-    "Back" : "Back",
+    "Back" : "بازگشت",
+    "Toggle selection for file \"{displayName}\"" : "Toggle selection for file \"{displayName}\"",
+    "Toggle selection for folder \"{displayName}\"" : "Toggle selection for folder \"{displayName}\"",
+    "File is loading" : "File is loading",
+    "Folder is loading" : "Folder is loading",
     "Filename" : "نام پرونده",
     "Folder name" : "نام پوشه",
     "This node is unavailable" : "گره شما در دسترس نیست",
+    "Another entry with the same name already exists." : "Another entry with the same name already exists.",
+    "Invalid filename." : "Invalid filename.",
     "Renamed \"{oldName}\" to \"{newName}\"" : "تغییر نام \"{oldName}\" به \"{newName}\"",
     "Rename file" : "تغییر نام فایل",
+    "Folder" : "پوشه",
+    "Unknown file type" : "Unknown file type",
+    "{ext} image" : "{ext} image",
+    "{ext} video" : "{ext} video",
+    "{ext} audio" : "{ext} audio",
+    "{ext} text" : "{ext} text",
     "Pending" : "در انتظار",
+    "Unknown date" : "Unknown date",
     "Clear filter" : "پاک کردن پالایه",
     "Modified" : "تاریخ",
+    "Search everywhere" : "جستجو در هر کجا.",
     "Type" : "نوع",
-    "Active filters" : "Active filters",
-    "Remove filter" : "Remove filter",
+    "Active filters" : "فیلترهای فعال",
+    "Remove filter" : "فیلتر را بردارید",
     "Total rows summary" : "خلاصه کل ردیف ها",
+    "Toggle selection for all files and folders" : "Toggle selection for all files and folders",
     "Name" : "نام",
+    "File type" : "File type",
     "Size" : "اندازه",
-    "\"{displayName}\" batch action executed successfully" : "عملکرد دسته‌ای \"{displayName}\" با موفقیت اجرا شد",
-    "\"{displayName}\" action failed" : "اقدام \"{displayName}\" ناموفق بود",
     "Actions" : "فعالیت ها",
+    "(selected)" : "(selected)",
     "List of files and folders." : "لیست فایل ها و پوشه ها",
+    "You have used your space quota and cannot upload files anymore." : "You have used your space quota and cannot upload files anymore.",
+    "Column headers with buttons are sortable." : "Column headers with buttons are sortable.",
     "This list is not fully rendered for performance reasons. The files will be rendered as you navigate through the list." : "این لیست به دلایل عملکرد به طور کامل ارائه نشده است. در حین حرکت در لیست، فایل ها ارائه می شوند.",
     "File not found" : "فایل یافت نشد",
     "{usedQuotaByte} used" : "{usedQuotaByte} استفاده شده است",
     "{used} of {quota} used" : "{used} از {quota} استفاده شده",
+    "{relative}% used" : "{relative}% used",
     "Could not refresh storage stats" : "نمی‌توان آمار ذخیره‌سازی را بازخوانی کرد",
     "Your storage is full, files can not be updated or synced anymore!" : "فضای ذخیره ی شما کاملا پر است، بیش از این فایلها بهنگام یا همگام سازی نمی توانند بشوند!",
+    "Storage information" : "اطلاعات ذخیره‌سازی",
+    "Storage quota" : "محدودیت ذخیره‌سازی",
     "New folder" : "پوشه جدید",
     "Create new folder" : "ساختن پوشه جدید",
-    "Create" : "ساخت",
+    "This name is already in use." : "This name is already in use.",
+    "Create" : "ایجاد",
+    "Fill template fields" : "Fill template fields",
+    "Submitting fields …" : "Submitting fields …",
     "Submit" : "ارسال",
     "Choose a file or folder to transfer" : "فایل یا پوشه ای را برای انتقال انتخاب کنید",
     "Transfer" : "انتقال",
@@ -102,16 +147,29 @@ OC.L10N.register(
     "Choose file or folder to transfer" : "فایل یا پوشه را برای انتقال انتخاب کنید",
     "Change" : "تغییر",
     "New owner" : "مالک جدید",
+    "Keep {old}" : "Keep {old}",
+    "Keep without extension" : "Keep without extension",
+    "Use {new}" : "Use {new}",
+    "Remove extension" : "Remove extension",
+    "Change file extension" : "Change file extension",
+    "Changing the file extension from \"{old}\" to \"{new}\" may render the file unreadable." : "Changing the file extension from \"{old}\" to \"{new}\" may render the file unreadable.",
+    "Removing the file extension \"{old}\" may render the file unreadable." : "Removing the file extension \"{old}\" may render the file unreadable.",
+    "Adding the file extension \"{new}\" may render the file unreadable." : "Adding the file extension \"{new}\" may render the file unreadable.",
+    "Do not show this dialog again." : "Do not show this dialog again.",
     "Select file or folder to link to" : "فایل یا پوشه را برای پیوند انتخاب کنید",
     "Choose {file}" : "انتخاب {file}",
     "Share" : "اشتراک‌گذاری",
     "Shared by link" : "اشتراک گذاشته شده از طریق لینک",
     "Shared" : "به اشتراک گذاشته شده ",
-    "Switch to list view" : "Switch to list view",
+    "Switch to list view" : "تغییر به نمای لیست",
+    "Switch to grid view" : "Switch to grid view",
+    "The file could not be found" : "The file could not be found",
     "Upload was cancelled by user" : "آپلود توسط کاربر لغو شد",
     "Not enough free space" : "فضای کافی در دسترس نیست",
     "Operation is blocked by access control" : "مدیریت دسترسی، عملیات را متوقف کرد",
-    "\"{displayName}\" action executed successfully" : "عملکرد \"{displayName}\" با موفقیت اجرا شد",
+    "Error during upload: {message}" : "Error during upload: {message}",
+    "Error during upload, status code {status}" : "Error during upload, status code {status}",
+    "Unknown error during upload" : "Unknown error during upload",
     "Loading current folder" : "در حال بارگیری پوشه فعلی",
     "Retry" : "تلاش دوباره",
     "No files in here" : "هیچ فایلی اینجا وجود ندارد",
@@ -119,22 +177,39 @@ OC.L10N.register(
     "Go back" : "برگرد",
     "Views" : "بازدیدها",
     "Files settings" : "تنظیمات پرونده‌ها",
-    "Open in files" : "Open in files",
+    "Your files" : "Your files",
+    "Open in files" : "باز کردن در فایل‌ها",
     "File cannot be accessed" : "فایل قابل دسترسی نیست",
+    "The file could not be found or you do not have permissions to view it. Ask the sender to share it." : "The file could not be found or you do not have permissions to view it. Ask the sender to share it.",
     "Clipboard is not available" : "کلیپ بورد در دسترس نیست",
-    "WebDAV URL copied to clipboard" : "URL WebDAV در کلیپ بورد کپی شد",
+    "General" : "عمومی",
+    "All files" : "تمامی فایل‌ها",
+    "Personal files" : "فایل‌های شخصی",
     "Sort favorites first" : "ابتدا موارد دلخواه را مرتب کنید",
+    "Sort folders before files" : "Sort folders before files",
+    "Appearance" : "ظاهر",
     "Show hidden files" : "نمایش پرونده‌های مخفی",
+    "Show file type column" : "Show file type column",
     "Crop image previews" : "پیش نمایش تصویر برش",
     "Additional settings" : "تنظیمات اضافی",
     "WebDAV" : "WebDAV",
-    "Copy to clipboard" : "کپی به کلیپ بورد",
-    "Use this address to access your Files via WebDAV" : "از این آدرس برای دسترسی به فایل های خود از طریق WebDAV استفاده کنید",
-    "If you have enabled 2FA, you must create and use a new app password by clicking here." : "اگر 2FA را فعال کرده اید، باید با کلیک کردن در اینجا یک رمز عبور برنامه جدید ایجاد و استفاده کنید.",
+    "WebDAV URL" : "WebDAV URL",
+    "Copy" : "رونوشت",
+    "Warnings" : "Warnings",
     "Keyboard shortcuts" : "میان‌برهای صفحه‌کلید",
+    "File actions" : "File actions",
+    "Rename" : "تغییرنام",
+    "Delete" : "حذف",
+    "Manage tags" : "مدیریت برچسب ها",
     "Selection" : "انتخاب",
+    "Select all files" : "Select all files",
+    "Deselect all" : "لغو انتخاب همه",
     "Navigation" : "جهت یابی",
     "View" : "نمایش",
+    "Toggle grid view" : "نمای دریچه را تغییر دهید",
+    "Show those shortcuts" : "Show those shortcuts",
+    "You" : "You",
+    "Shared multiple times with different people" : "Shared multiple times with different people",
     "Error while loading the file data" : "خطا هنگام بارگیری داده های فایل",
     "Owner" : "مالک",
     "Remove from favorites" : "حذف کردن از برگزیده ها",
@@ -145,55 +220,123 @@ OC.L10N.register(
     "Pick a template for {name}" : "یک الگو برای {name} انتخاب کنید",
     "Create a new file with the selected template" : "یک فایل جدید با الگوی انتخاب شده ایجاد کنید",
     "Creating file" : "ایجاد فایل",
+    "Save as {displayName}" : "Save as {displayName}",
+    "Save as …" : "Save as …",
+    "Converting files …" : "Converting files …",
+    "Failed to convert files: {message}" : "Failed to convert files: {message}",
+    "All files failed to be converted" : "All files failed to be converted",
+    "One file could not be converted: {message}" : "One file could not be converted: {message}",
+    "_One file could not be converted_::_%n files could not be converted_" : ["One file could not be converted","%n files could not be converted"],
+    "_One file successfully converted_::_%n files successfully converted_" : ["One file successfully converted","%n files successfully converted"],
+    "Files successfully converted" : "Files successfully converted",
+    "Failed to convert files" : "Failed to convert files",
+    "Converting file …" : "Converting file …",
+    "File successfully converted" : "File successfully converted",
+    "Failed to convert file: {message}" : "Failed to convert file: {message}",
+    "Failed to convert file" : "Failed to convert file",
     "Leave this share" : "ترک این اشتراک",
+    "Leave these shares" : "Leave these shares",
     "Disconnect storage" : "فضای ذخیره را جدا کنید",
+    "Disconnect storages" : "Disconnect storages",
     "Delete permanently" : "حذف قطعی",
+    "Delete and unshare" : "Delete and unshare",
     "Delete file" : "حذف پرونده",
-    "Delete files" : "Delete files",
+    "Delete files" : "حذف فایل‌ها",
     "Delete folder" : "حذف پوشه",
-    "Delete" : "حذف",
+    "Delete folders" : "Delete folders",
+    "_You are about to permanently delete {count} item_::_You are about to permanently delete {count} items_" : ["You are about to permanently delete {count} item","You are about to permanently delete {count} items"],
+    "_You are about to delete {count} item_::_You are about to delete {count} items_" : ["You are about to delete {count} item","You are about to delete {count} items"],
+    "Confirm deletion" : "Confirm deletion",
     "Cancel" : "لغو",
+    "Download" : "دانلود",
+    "Moving \"{source}\" to \"{destination}\" …" : "Moving \"{source}\" to \"{destination}\" …",
+    "Copying \"{source}\" to \"{destination}\" …" : "Copying \"{source}\" to \"{destination}\" …",
+    "You cannot move a file/folder onto itself or into a subfolder of itself" : "You cannot move a file/folder onto itself or into a subfolder of itself",
+    "(copy)" : "(copy)",
+    "(copy %n)" : "(copy %n)",
+    "A file or folder with that name already exists in this folder" : "A file or folder with that name already exists in this folder",
+    "The files are locked" : "The files are locked",
+    "The file does not exist anymore" : "The file does not exist anymore",
+    "Choose destination" : "Choose destination",
     "Copy to {target}" : "رونوشت به {target}",
-    "Copy" : "رونوشت",
     "Move to {target}" : "جابجایی به {target}",
     "Move" : "انتقال",
+    "Move or copy operation failed" : "Move or copy operation failed",
     "Move or copy" : "انتقال یا رونوشت",
     "Open folder {displayName}" : "باز کردن پوشه {displayName}",
     "Open in Files" : "در فایل باز کنید",
-    "Open file locally" : "گشودن محلی پرونده",
-    "Failed to redirect to client" : "هدایت به مشتری انجام نشد",
     "Open locally" : "گشودن محلی",
-    "Rename" : "تغییرنام",
-    "Open details" : "باز کردن جزئیات",
+    "Failed to redirect to client" : "هدایت به مشتری انجام نشد",
+    "Open file locally" : "گشودن محلی پرونده",
+    "The file should now open on your device. If it doesn't, please check that you have the desktop app installed." : "The file should now open on your device. If it doesn't, please check that you have the desktop app installed.",
+    "Retry and close" : "Retry and close",
+    "Open online" : "Open online",
+    "Details" : "جزئیات",
     "View in folder" : "مشاهده در پوشه",
     "Today" : "امروز",
     "Last 7 days" : "۷ روز گذشته",
     "Last 30 days" : "۳۰ روز گذشته",
+    "This year ({year})" : "This year ({year})",
+    "Last year ({year})" : "Last year ({year})",
     "Documents" : "سندها",
+    "Spreadsheets" : "Spreadsheets",
+    "Presentations" : "Presentations",
+    "PDFs" : "PDFs",
+    "Folders" : "Folders",
     "Audio" : "صدا",
+    "Images" : "تصاویر",
     "Videos" : "فیلم ها ",
+    "Created new folder \"{name}\"" : "Created new folder \"{name}\"",
     "Unable to initialize the templates directory" : "راه اندازی دایرکتوری الگوها ممکن نیست",
+    "Create templates folder" : "Create templates folder",
     "Templates" : "قالب‌ها",
+    "New template folder" : "New template folder",
+    "In folder" : "In folder",
+    "Search in folder: {folder}" : "Search in folder: {folder}",
+    "One of the dropped files could not be processed" : "One of the dropped files could not be processed",
+    "Your browser does not support the Filesystem API. Directories will not be uploaded" : "Your browser does not support the Filesystem API. Directories will not be uploaded",
+    "No files to upload" : "No files to upload",
+    "Unable to create the directory {directory}" : "Unable to create the directory {directory}",
+    "Some files could not be uploaded" : "Some files could not be uploaded",
+    "Files uploaded successfully" : "Files uploaded successfully",
+    "No files to process" : "No files to process",
+    "Some files could not be copied" : "Some files could not be copied",
     "Some files could not be moved" : "برخی از پرونده‌ها قابل انتقال نیستند",
+    "Files copied successfully" : "Files copied successfully",
+    "Files moved successfully" : "Files moved successfully",
+    "Conflicts resolution skipped" : "Conflicts resolution skipped",
+    "Upload cancelled" : "Upload cancelled",
+    "Could not rename \"{oldName}\", it does not exist any more" : "نمی‌توان نام «{oldName}» را تغییر داد، دیگر وجود ندارد",
+    "The name \"{newName}\" is already used in the folder \"{dir}\". Please choose a different name." : "نام \"{newName}\" در پوشه \"{dir}\" به کار رفته است.\nلطفا نام دیگری برگزینید.",
+    "Could not rename \"{oldName}\"" : "تغییر نام \"{oldName}\" ممکن نیست",
     "This operation is forbidden" : "این عملیات غیرمجاز است",
-    "This directory is unavailable, please check the logs or contact the administrator" : "پوشه‌ در دسترس نیست، لطفا لاگ‌ها را بررسی کنید یا به مدیر سیستم اطلاع دهید",
     "Storage is temporarily not available" : "ذخیره سازی به طور موقت در دسترس نیست",
-    "_{folderCount} folder_::_{folderCount} folders_" : ["{folderCount} پوشه","{folderCount} پوشه"],
-    "_{fileCount} file_::_{fileCount} files_" : ["{fileCount} پرونده","{fileCount} پرونده"],
+    "Unexpected error: {error}" : "Unexpected error: {error}",
+    "_%n file_::_%n files_" : ["%n فایل","%n فایل"],
+    "_%n folder_::_%n folders_" : ["%n پوشه","%n پوشه"],
+    "_%n hidden_::_%n hidden_" : ["%n hidden","%n hidden"],
+    "Filename must not be empty." : "Filename must not be empty.",
+    "\"{char}\" is not allowed inside a filename." : "\"{char}\" is not allowed inside a filename.",
+    "\"{segment}\" is a reserved name and not allowed for filenames." : "\"{segment}\" is a reserved name and not allowed for filenames.",
+    "\"{extension}\" is not an allowed filetype." : "\"{extension}\" is not an allowed filetype.",
+    "Filenames must not end with \"{extension}\"." : "Filenames must not end with \"{extension}\".",
+    "List of favorite files and folders." : "List of favorite files and folders.",
     "No favorites yet" : "هنوز مورد دلخواه وجود ندارد",
     "Files and folders you mark as favorite will show up here" : "فایل‌ها و پوشه‌های انتخاب شده به عنوان برگزیده توسط شما، در اینجا نمایش داده می‌شود",
-    "All files" : "تمامی فایل‌ها",
-    "Personal files" : "فایل‌های شخصی",
+    "List of your files and folders." : "List of your files and folders.",
+    "List of your files and folders that are not shared." : "List of your files and folders that are not shared.",
+    "No personal files found" : "No personal files found",
+    "Files that are not shared will show up here." : "Files that are not shared will show up here.",
     "Recent" : "اخیر",
     "List of recently modified files and folders." : "فهرست فایل‌ها و پوشه‌هایی که اخیراً اصلاح شده‌اند.",
     "No recently modified files" : "هیچ فایلی که اخیراً اصلاح شده است",
     "Files and folders you recently modified will show up here." : "فایل‌ها و پوشه‌هایی که اخیراً تغییر داده‌اید در اینجا نمایش داده می‌شوند.",
+    "Search" : "جستجو",
     "No entries found in this folder" : "هیچ ورودی‌ای در این پوشه وجود ندارد",
     "Select all" : "انتخاب همه",
     "Upload too large" : "سایز فایل برای آپلود زیاد است(م.تنظیمات در php.ini)",
     "The files you are trying to upload exceed the maximum size for file uploads on this server." : "فایلها بیش از حد تعیین شده در این سرور هستند\nمترجم:با تغییر فایل php,ini میتوان این محدودیت را برطرف کرد",
     "File could not be found" : "پرونده پیدا نشد",
-    "Download" : "دانلود",
     "Show list view" : "نمایش فهرستی",
     "Show grid view" : "نمایش شبکه‌ای",
     "Close" : "بستن",
@@ -208,30 +351,30 @@ OC.L10N.register(
     "An unknown error has occurred" : "خطایی ناشناخته اتفاق افتاده است",
     "File could not be uploaded" : "پرونده بارگذاری نشد",
     "Uploading …" : "بارگذاری...",
-    "{remainingTime} ({currentNumber}/{total})" : "{remainingTime} ({currentNumber}/{total})",
+    "{remainingTime} ({currentNumber}/{total})" : "{remainingTime}({currentNumber} /{total} )",
     "Uploading … ({currentNumber}/{total})" : "در حال بارگذاری ... ({currentNumber}/{total})",
     "{loadedSize} of {totalSize} ({bitrate})" : "{loadedSize} از {totalSize} ({bitrate})",
     "Uploading that item is not supported" : "بارگذاری آن مورد پشتیبانی نمی‌شود",
     "Error when assembling chunks, status code {status}" : "خطا هنگام جمع آوری قطعه ها، کد وضعیت {status}",
     "Choose target folder" : "پوشهٔ هدف را انتخاب کنید",
-    "Set reminder" : "Set reminder",
+    "Set reminder" : "تنظیم یادآوری",
     "Edit locally" : "ویرایش محلی",
     "Open" : "باز کردن",
     "Could not load info for file \"{file}\"" : "بارگیری اطلاعات برای پرونده امکان پذیر نیست \"{file}\"",
-    "Details" : "جزئیات",
     "Please select tag(s) to add to the selection" : "لطفاً برچسب(های) را برای افزودن به انتخاب انتخاب کنید",
     "Apply tag(s) to selection" : "تگ(ها) را در انتخاب اعمال کنید",
     "Select directory \"{dirName}\"" : "دایرکتوری \"{dirName}\" را انتخاب کنید",
     "Select file \"{fileName}\"" : "فایل \"{fileName}\" را انتخاب کنید",
     "Unable to determine date" : "امکان تعیین تاریخ وجود ندارد",
+    "This directory is unavailable, please check the logs or contact the administrator" : "پوشه‌ در دسترس نیست، لطفا لاگ‌ها را بررسی کنید یا به مدیر سیستم اطلاع دهید",
     "Could not move \"{file}\", target exists" : "انتقال\"{file}\" امکان پذیر نیست ، هدف وجود دارد",
     "Could not move \"{file}\"" : "پروندهٔ \"{file}\" منتقل نمی‌شود",
     "copy" : "کپی",
+    "Could not copy \"{file}\", target exists" : "Could not copy \"{file}\", target exists",
+    "Could not copy \"{file}\"" : "Could not copy \"{file}\"",
+    "Copied {origin} inside {destination}" : "Copied {origin} inside {destination}",
     "Copied {origin} and {nbfiles} other files inside {destination}" : "رونوشت شده از {origin} و {nbfiles} پرونده‌های دیگر در {destination}",
     "{newName} already exists" : "{newName} قبلاً موجود است",
-    "Could not rename \"{fileName}\", it does not exist any more" : "نمی‌توان نام «{fileName}» را تغییر داد، دیگر وجود ندارد",
-    "The name \"{targetName}\" is already used in the folder \"{dir}\". Please choose a different name." : "عنوان \"{targetName}\" هم اکنون در پوشه \"{dir}\" وجود دارد. لطفا نام دیگری انتخاب کنید",
-    "Could not rename \"{fileName}\"" : "\"{fileName}\" تغییر نام داده نمی‌شود",
     "Could not create file \"{file}\"" : "پروندهٔ \"{file}\" ساخته نشد",
     "Could not create file \"{file}\" because it already exists" : "نمی توان پرونده \"{file}\" ایجاد کرد زیرا در حال حاضر وجود دارد",
     "Could not create folder \"{dir}\" because it already exists" : "شاخه \"{dir}\" به علت موجود بودن ساخته نشد",
@@ -239,8 +382,6 @@ OC.L10N.register(
     "Error deleting file \"{fileName}\"." : "خطای حذف پروندهٔ \"{fileName}\".",
     "No search results in other folders for {tag}{filter}{endtag}" : "جستجو در پوشه های دیگر برای {tag}{filter}{endtag} یافت نشد",
     "Enter more than two characters to search in other folders" : "برای جستجو در پوشه های دیگر بیش از دو کاراکتر وارد کنید",
-    "_%n folder_::_%n folders_" : ["%n پوشه","%n پوشه"],
-    "_%n file_::_%n files_" : ["%n فایل","%n فایل"],
     "{dirs} and {files}" : "{dirs} و {files}",
     "_including %n hidden_::_including %n hidden_" : ["از جمله %nپنهان","از جمله %nپنهان"],
     "You do not have permission to upload or create files here" : "شما اجازه آپلود یا ایجاد فایل در اینجا را ندارید",
@@ -263,19 +404,65 @@ OC.L10N.register(
     "External storage \"{mountPoint}\" is almost full ({usedSpacePercent}%)." : "حافظه خارجی \"{mountPoint}\" تقریباً پر است ({usedSpacePercent}%).",
     "Your storage is almost full ({usedSpacePercent}%)." : "فضای ذخیره‌سازی شما تقریباً پر است ({usedSpacePercent}%).",
     "_matches \"{filter}\"_::_match \"{filter}\"_" : ["مطابقت با \"{filter}\"","مطابقت با \"{filter}\""],
+    "Direct link was copied (only works for people who have access to this file/folder)" : "Direct link was copied (only works for people who have access to this file/folder)",
     "Path" : "مسیر",
     "_%n byte_::_%n bytes_" : ["%n بایت","%n بایت"],
-    "Favorited" : "برگزیده شده",
+    "Favored" : "Favored",
+    "Favor" : "Favor",
+    "Copy direct link (only works for people who have access to this file/folder)" : "Copy direct link (only works for people who have access to this file/folder)",
     "Upload file" : "بارگذاری پرونده",
-    "Not favorited" : "مورد علاقه نیست",
+    "Not favored" : "Not favored",
     "An error occurred while trying to update the tags" : "یک خطا در حین بروزرسانی برچسب‌ها رخ داده است",
-    "Storage informations" : "ذخیره سازی اطلاعات ",
-    "Go to the previous folder" : "به پوشه قبلی بروید",
-    "Open the files app settings" : "تنظیمات برنامه فایل ها را باز کنید",
-    "Unable to change the favourite state of the file" : "امکان تغییر حالت دلخواه فایل وجود ندارد",
-    "Create new templates folder" : "پوشه قالب های جدید ایجاد کنید",
-    "List of favorites files and folders." : "لیست فایل ها و پوشه های مورد علاقه",
+    "Upload (max. %s)" : "آپلود (بیشترین سایز %s)",
+    "\"{displayName}\" action executed successfully" : "عملکرد \"{displayName}\" با موفقیت اجرا شد",
+    "\"{displayName}\" action failed" : "اقدام \"{displayName}\" ناموفق بود",
+    "\"{displayName}\" failed on some elements" : "\"{displayName}\" failed on some elements",
+    "\"{displayName}\" batch action executed successfully" : "عملکرد دسته‌ای \"{displayName}\" با موفقیت اجرا شد",
+    "Submitting fields…" : "Submitting fields…",
+    "Filter filenames…" : "Filter filenames…",
+    "WebDAV URL copied to clipboard" : "URL WebDAV در کلیپ بورد کپی شد",
+    "Enable the grid view" : "Enable the grid view",
+    "Enable folder tree" : "Enable folder tree",
+    "Copy to clipboard" : "کپی به کلیپ بورد",
+    "Use this address to access your Files via WebDAV" : "از این آدرس برای دسترسی به فایل های خود از طریق WebDAV استفاده کنید",
+    "If you have enabled 2FA, you must create and use a new app password by clicking here." : "اگر 2FA را فعال کرده اید، باید با کلیک کردن در اینجا یک رمز عبور برنامه جدید ایجاد و استفاده کنید.",
+    "Deletion cancelled" : "Deletion cancelled",
+    "Move cancelled" : "Move cancelled",
+    "Cancelled move or copy of \"{filename}\"." : "Cancelled move or copy of \"{filename}\".",
+    "Cancelled move or copy operation" : "Cancelled move or copy operation",
+    "Open details" : "باز کردن جزئیات",
+    "Photos and images" : "Photos and images",
+    "New folder creation cancelled" : "New folder creation cancelled",
+    "_{folderCount} folder_::_{folderCount} folders_" : ["{folderCount} پوشه","{folderCount} پوشه"],
+    "_{fileCount} file_::_{fileCount} files_" : ["{fileCount} پرونده","{fileCount} پرونده"],
+    "_1 file and {folderCount} folder_::_1 file and {folderCount} folders_" : ["1 file and {folderCount} folder","1 file and {folderCount} folders"],
+    "_{fileCount} file and 1 folder_::_{fileCount} files and 1 folder_" : ["{fileCount} file and 1 folder","{fileCount} files and 1 folder"],
+    "{fileCount} files and {folderCount} folders" : "{fileCount} files and {folderCount} folders",
+    "All folders" : "All folders",
+    "Personal Files" : "Personal Files",
     "Text file" : "فایل متنی",
-    "New text file.txt" : "پروندهٔ متنی جدید با پسوند txt"
+    "New text file.txt" : "پروندهٔ متنی جدید با پسوند txt",
+    "%1$s (renamed)" : "%1$s (renamed)",
+    "renamed file" : "renamed file",
+    "After enabling the windows compatible filenames, existing files cannot be modified anymore but can be renamed to valid new names by their owner." : "After enabling the windows compatible filenames, existing files cannot be modified anymore but can be renamed to valid new names by their owner.",
+    "Filter file names …" : "Filter file names …",
+    "Prevent warning dialogs from open or reenable them." : "Prevent warning dialogs from open or reenable them.",
+    "Show a warning dialog when changing a file extension." : "Show a warning dialog when changing a file extension.",
+    "Speed up your Files experience with these quick shortcuts." : "Speed up your Files experience with these quick shortcuts.",
+    "Open the actions menu for a file" : "Open the actions menu for a file",
+    "Rename a file" : "Rename a file",
+    "Delete a file" : "Delete a file",
+    "Favorite or remove a file from favorites" : "Favorite or remove a file from favorites",
+    "Manage tags for a file" : "Manage tags for a file",
+    "Deselect all files" : "Deselect all files",
+    "Select or deselect a file" : "Select or deselect a file",
+    "Select a range of files" : "Select a range of files",
+    "Navigate to the parent folder" : "Navigate to the parent folder",
+    "Navigate to the file above" : "Navigate to the file above",
+    "Navigate to the file below" : "Navigate to the file below",
+    "Navigate to the file on the left (in grid mode)" : "Navigate to the file on the left (in grid mode)",
+    "Navigate to the file on the right (in grid mode)" : "Navigate to the file on the right (in grid mode)",
+    "Toggle the grid view" : "Toggle the grid view",
+    "Open the sidebar for a file" : "Open the sidebar for a file"
 },
 "nplurals=2; plural=(n > 1);");
