@@ -42,7 +42,6 @@ OC.L10N.register(
     "Files" : "ფაილები",
     "A file or folder has been <strong>changed</strong>" : "A file or folder has been <strong>changed</strong>",
     "A favorite file or folder has been <strong>changed</strong>" : "A favorite file or folder has been <strong>changed</strong>",
-    "Upload (max. %s)" : "Upload (max. %s)",
     "Accept" : "Accept",
     "Reject" : "Reject",
     "Incoming ownership transfer from {user}" : "Incoming ownership transfer from {user}",
@@ -69,22 +68,23 @@ OC.L10N.register(
     "This node is unavailable" : "This node is unavailable",
     "Renamed \"{oldName}\" to \"{newName}\"" : "Renamed \"{oldName}\" to \"{newName}\"",
     "Rename file" : "Rename file",
+    "Folder" : "Folder",
     "Pending" : "Pending",
     "Clear filter" : "Clear filter",
     "Modified" : "Modified",
+    "Search everywhere" : "მოძებნე ყველგან",
     "Type" : "Type",
     "Active filters" : "Active filters",
     "Remove filter" : "Remove filter",
     "Total rows summary" : "Total rows summary",
     "Name" : "Name",
     "Size" : "Size",
-    "\"{displayName}\" batch action executed successfully" : "\"{displayName}\" batch action executed successfully",
-    "\"{displayName}\" action failed" : "\"{displayName}\" action failed",
     "Actions" : "Actions",
     "List of files and folders." : "List of files and folders.",
     "Column headers with buttons are sortable." : "Column headers with buttons are sortable.",
     "This list is not fully rendered for performance reasons. The files will be rendered as you navigate through the list." : "This list is not fully rendered for performance reasons. The files will be rendered as you navigate through the list.",
     "File not found" : "File not found",
+    "_{count} selected_::_{count} selected_" : ["{count} selected","{count} selected"],
     "{usedQuotaByte} used" : "{usedQuotaByte} used",
     "{used} of {quota} used" : "{used} of {quota} used",
     "{relative}% used" : "{relative}% used",
@@ -116,7 +116,6 @@ OC.L10N.register(
     "Operation is blocked by access control" : "Operation is blocked by access control",
     "Error during upload: {message}" : "Error during upload: {message}",
     "Unknown error during upload" : "Unknown error during upload",
-    "\"{displayName}\" action executed successfully" : "\"{displayName}\" action executed successfully",
     "Loading current folder" : "Loading current folder",
     "Retry" : "Retry",
     "No files in here" : "No files in here",
@@ -126,20 +125,22 @@ OC.L10N.register(
     "Files settings" : "Files settings",
     "File cannot be accessed" : "File cannot be accessed",
     "Clipboard is not available" : "Clipboard is not available",
-    "WebDAV URL copied to clipboard" : "WebDAV URL copied to clipboard",
+    "General" : "General",
+    "All files" : "All files",
     "Sort favorites first" : "Sort favorites first",
     "Show hidden files" : "Show hidden files",
     "Crop image previews" : "Crop image previews",
-    "Enable the grid view" : "Enable the grid view",
     "Additional settings" : "Additional settings",
     "WebDAV" : "WebDAV",
     "WebDAV URL" : "WebDAV URL",
-    "Copy to clipboard" : "Copy to clipboard",
-    "Use this address to access your Files via WebDAV" : "Use this address to access your Files via WebDAV",
-    "If you have enabled 2FA, you must create and use a new app password by clicking here." : "If you have enabled 2FA, you must create and use a new app password by clicking here.",
+    "Copy" : "Copy",
     "Keyboard shortcuts" : "Keyboard shortcuts",
+    "Rename" : "Rename",
+    "Delete" : "Delete",
+    "Deselect all" : "Deselect all",
     "Navigation" : "Navigation",
     "View" : "View",
+    "Toggle grid view" : "Toggle grid view",
     "You" : "You",
     "Error while loading the file data" : "Error while loading the file data",
     "Owner" : "Owner",
@@ -156,59 +157,57 @@ OC.L10N.register(
     "Delete permanently" : "Delete permanently",
     "Delete file" : "Delete file",
     "Delete folder" : "Delete folder",
-    "Delete" : "Delete",
     "Cancel" : "Cancel",
+    "Download" : "Download",
+    "Destination is not a folder" : "Destination is not a folder",
+    "This file/folder is already in that directory" : "This file/folder is already in that directory",
     "You cannot move a file/folder onto itself or into a subfolder of itself" : "You cannot move a file/folder onto itself or into a subfolder of itself",
     "A file or folder with that name already exists in this folder" : "A file or folder with that name already exists in this folder",
     "The file does not exist anymore" : "The file does not exist anymore",
     "Choose destination" : "Choose destination",
     "Copy to {target}" : "Copy to {target}",
-    "Copy" : "Copy",
     "Move to {target}" : "Move to {target}",
     "Move" : "Move",
     "Move or copy" : "Move or copy",
-    "Cancelled move or copy operation" : "Cancelled move or copy operation",
     "Open folder {displayName}" : "Open folder {displayName}",
     "Open in Files" : "Open in Files",
-    "Open file locally" : "Open file locally",
-    "Failed to redirect to client" : "Failed to redirect to client",
     "Open locally" : "Open locally",
-    "Rename" : "Rename",
-    "Open details" : "Open details",
+    "Failed to redirect to client" : "Failed to redirect to client",
+    "Open file locally" : "Open file locally",
+    "Details" : "Details",
     "View in folder" : "View in folder",
     "Today" : "დღეს",
     "Last 7 days" : "Last 7 days",
     "Last 30 days" : "Last 30 days",
     "Documents" : "Documents",
     "Audio" : "Audio",
+    "Images" : "Images",
     "Videos" : "Videos",
     "Created new folder \"{name}\"" : "Created new folder \"{name}\"",
     "Unable to initialize the templates directory" : "Unable to initialize the templates directory",
     "Templates" : "Templates",
     "One of the dropped files could not be processed" : "One of the dropped files could not be processed",
     "Some files could not be moved" : "Some files could not be moved",
+    "Could not rename \"{oldName}\", it does not exist any more" : "Could not rename \"{oldName}\", it does not exist any more",
+    "The name \"{newName}\" is already used in the folder \"{dir}\". Please choose a different name." : "The name \"{newName}\" is already used in the folder \"{dir}\". Please choose a different name.",
+    "Could not rename \"{oldName}\"" : "Could not rename \"{oldName}\"",
     "This operation is forbidden" : "This operation is forbidden",
-    "This directory is unavailable, please check the logs or contact the administrator" : "This directory is unavailable, please check the logs or contact the administrator",
     "Storage is temporarily not available" : "Storage is temporarily not available",
-    "_{folderCount} folder_::_{folderCount} folders_" : ["{folderCount} folder","{folderCount} folders"],
-    "_{fileCount} file_::_{fileCount} files_" : ["{fileCount} file","{fileCount} files"],
-    "_1 file and {folderCount} folder_::_1 file and {folderCount} folders_" : ["1 file and {folderCount} folder","1 file and {folderCount} folders"],
-    "_{fileCount} file and 1 folder_::_{fileCount} files and 1 folder_" : ["{fileCount} file and 1 folder","{fileCount} files and 1 folder"],
-    "{fileCount} files and {folderCount} folders" : "{fileCount} files and {folderCount} folders",
+    "_%n file_::_%n files_" : ["%n file","%n files"],
+    "_%n folder_::_%n folders_" : ["%n folder","%n folders"],
     "No favorites yet" : "No favorites yet",
     "Files and folders you mark as favorite will show up here" : "Files and folders you mark as favorite will show up here",
-    "All files" : "All files",
     "List of your files and folders." : "List of your files and folders.",
     "Recent" : "Recent",
     "List of recently modified files and folders." : "List of recently modified files and folders.",
     "No recently modified files" : "No recently modified files",
     "Files and folders you recently modified will show up here." : "Files and folders you recently modified will show up here.",
+    "Search" : "ძიება",
     "No entries found in this folder" : "No entries found in this folder",
     "Select all" : "Select all",
     "Upload too large" : "Upload too large",
     "The files you are trying to upload exceed the maximum size for file uploads on this server." : "The files you are trying to upload exceed the maximum size for file uploads on this server.",
     "File could not be found" : "File could not be found",
-    "Download" : "Download",
     "Show list view" : "Show list view",
     "Show grid view" : "Show grid view",
     "Close" : "Close",
@@ -233,12 +232,12 @@ OC.L10N.register(
     "Edit locally" : "Edit locally",
     "Open" : "Open",
     "Could not load info for file \"{file}\"" : "Could not load info for file \"{file}\"",
-    "Details" : "Details",
     "Please select tag(s) to add to the selection" : "Please select tag(s) to add to the selection",
     "Apply tag(s) to selection" : "Apply tag(s) to selection",
     "Select directory \"{dirName}\"" : "Select directory \"{dirName}\"",
     "Select file \"{fileName}\"" : "Select file \"{fileName}\"",
     "Unable to determine date" : "Unable to determine date",
+    "This directory is unavailable, please check the logs or contact the administrator" : "This directory is unavailable, please check the logs or contact the administrator",
     "Could not move \"{file}\", target exists" : "Could not move \"{file}\", target exists",
     "Could not move \"{file}\"" : "Could not move \"{file}\"",
     "copy" : "copy",
@@ -247,9 +246,6 @@ OC.L10N.register(
     "Copied {origin} inside {destination}" : "Copied {origin} inside {destination}",
     "Copied {origin} and {nbfiles} other files inside {destination}" : "Copied {origin} and {nbfiles} other files inside {destination}",
     "{newName} already exists" : "{newName} already exists",
-    "Could not rename \"{fileName}\", it does not exist any more" : "Could not rename \"{fileName}\", it does not exist any more",
-    "The name \"{targetName}\" is already used in the folder \"{dir}\". Please choose a different name." : "The name \"{targetName}\" is already used in the folder \"{dir}\". Please choose a different name.",
-    "Could not rename \"{fileName}\"" : "Could not rename \"{fileName}\"",
     "Could not create file \"{file}\"" : "Could not create file \"{file}\"",
     "Could not create file \"{file}\" because it already exists" : "Could not create file \"{file}\" because it already exists",
     "Could not create folder \"{dir}\" because it already exists" : "Could not create folder \"{dir}\" because it already exists",
@@ -257,8 +253,6 @@ OC.L10N.register(
     "Error deleting file \"{fileName}\"." : "Error deleting file \"{fileName}\".",
     "No search results in other folders for {tag}{filter}{endtag}" : "No search results in other folders for {tag}{filter}{endtag}",
     "Enter more than two characters to search in other folders" : "Enter more than two characters to search in other folders",
-    "_%n folder_::_%n folders_" : ["%n folder","%n folders"],
-    "_%n file_::_%n files_" : ["%n file","%n files"],
     "{dirs} and {files}" : "{dirs} and {files}",
     "_including %n hidden_::_including %n hidden_" : ["including %n hidden","including %n hidden"],
     "You do not have permission to upload or create files here" : "You do not have permission to upload or create files here",
@@ -283,17 +277,24 @@ OC.L10N.register(
     "_matches \"{filter}\"_::_match \"{filter}\"_" : ["matches \"{filter}\"","match \"{filter}\""],
     "Path" : "Path",
     "_%n byte_::_%n bytes_" : ["%n byte","%n bytes"],
-    "Favorited" : "Favorited",
     "Upload file" : "Upload file",
-    "Not favorited" : "Not favorited",
     "An error occurred while trying to update the tags" : "An error occurred while trying to update the tags",
-    "Storage informations" : "Storage informations",
-    "Choose file" : "Choose file",
-    "Go to the previous folder" : "Go to the previous folder",
-    "Open the files app settings" : "Open the files app settings",
-    "Unable to change the favourite state of the file" : "Unable to change the favourite state of the file",
-    "Create new templates folder" : "Create new templates folder",
-    "List of favorites files and folders." : "List of favorites files and folders.",
+    "Upload (max. %s)" : "Upload (max. %s)",
+    "\"{displayName}\" action executed successfully" : "\"{displayName}\" action executed successfully",
+    "\"{displayName}\" action failed" : "\"{displayName}\" action failed",
+    "\"{displayName}\" batch action executed successfully" : "\"{displayName}\" batch action executed successfully",
+    "WebDAV URL copied to clipboard" : "WebDAV URL copied to clipboard",
+    "Enable the grid view" : "Enable the grid view",
+    "Copy to clipboard" : "Copy to clipboard",
+    "Use this address to access your Files via WebDAV" : "Use this address to access your Files via WebDAV",
+    "If you have enabled 2FA, you must create and use a new app password by clicking here." : "If you have enabled 2FA, you must create and use a new app password by clicking here.",
+    "Cancelled move or copy operation" : "Cancelled move or copy operation",
+    "Open details" : "Open details",
+    "_{folderCount} folder_::_{folderCount} folders_" : ["{folderCount} folder","{folderCount} folders"],
+    "_{fileCount} file_::_{fileCount} files_" : ["{fileCount} file","{fileCount} files"],
+    "_1 file and {folderCount} folder_::_1 file and {folderCount} folders_" : ["1 file and {folderCount} folder","1 file and {folderCount} folders"],
+    "_{fileCount} file and 1 folder_::_{fileCount} files and 1 folder_" : ["{fileCount} file and 1 folder","{fileCount} files and 1 folder"],
+    "{fileCount} files and {folderCount} folders" : "{fileCount} files and {folderCount} folders",
     "Text file" : "Text file",
     "New text file.txt" : "New text file.txt"
 },
