@@ -98,8 +98,9 @@ OC.L10N.register(
     "People" : "People",
     "Expiration date" : "Expiration date",
     "Password" : "Password",
+    "Link copied" : "Link copied",
     "Share link" : "Share link",
-    "Copy to clipboard" : "Copy to clipboard",
+    "Copy" : "Copy",
     "Select" : "Select",
     "Close" : "Close",
     "Error creating the share: {errorMessage}" : "Error creating the share: {errorMessage}",
@@ -126,8 +127,7 @@ OC.L10N.register(
     "Via “{folder}”" : "Via “{folder}”",
     "Unshare" : "Unshare",
     "Cannot copy, please copy the link manually" : "Cannot copy, please copy the link manually",
-    "Copy internal link to clipboard" : "Copy internal link to clipboard",
-    "Link copied" : "Link copied",
+    "Copy internal link" : "Copy internal link",
     "Internal link" : "Internal link",
     "{shareWith} by {initiator}" : "{shareWith} by {initiator}",
     "Shared via link by {initiator}" : "Shared via link by {initiator}",
@@ -135,7 +135,6 @@ OC.L10N.register(
     "Share link ({label})" : "Share link ({label})",
     "Share link ({index})" : "Share link ({index})",
     "Actions for \"{title}\"" : "Actions for \"{title}\"",
-    "Copy public link of \"{title}\" to clipboard" : "Copy public link of \"{title}\" to clipboard",
     "Error, please enter proper password and/or expiration date" : "Error, please enter proper password and/or expiration date",
     "Link share created" : "Link share created",
     "Error while creating the share" : "Error while creating the share",
@@ -155,7 +154,7 @@ OC.L10N.register(
     "Name, email, or Federated Cloud ID …" : "Name, email, or Federated Cloud ID …",
     "Searching …" : "Searching …",
     "No elements found." : "No elements found.",
-    "Search globally" : "Search globally",
+    "Search everywhere" : "მოძებნე ყველგან",
     "Guest" : "Guest",
     "Group" : "Group",
     "Email" : "Email",
@@ -165,8 +164,6 @@ OC.L10N.register(
     "on {server}" : "on {server}",
     "File drop" : "File drop",
     "Terms of service" : "Terms of service",
-    "Nickname" : "Nickname",
-    "Share with {userName}" : "Share with {userName}",
     "Share with group" : "Share with group",
     "Share in conversation" : "Share in conversation",
     "Share with remote group" : "Share with remote group",
@@ -209,7 +206,6 @@ OC.L10N.register(
     "_Restore share_::_Restore shares_" : ["Restore share","Restore shares"],
     "Shared" : "Shared",
     "Shared by {ownerDisplayName}" : "Shared by {ownerDisplayName}",
-    "Show sharing options" : "Show sharing options",
     "Shared with others" : "Shared with others",
     "Overview of shared files." : "Overview of shared files.",
     "No shares" : "No shares",
@@ -245,15 +241,6 @@ OC.L10N.register(
     "Shared with you and {circle} by {owner}" : "Shared with you and {circle} by {owner}",
     "Shared with you and the conversation {conversation} by {owner}" : "Shared with you and the conversation {conversation} by {owner}",
     "Shared with you in a conversation by {owner}" : "Shared with you in a conversation by {owner}",
-    "Share note" : "Share note",
-    "Show list view" : "Show list view",
-    "Show grid view" : "Show grid view",
-    "Upload files to %s" : "Upload files to %s",
-    "Note" : "Note",
-    "Select or drop files" : "Select or drop files",
-    "Uploading files" : "Uploading files",
-    "Uploaded files:" : "Uploaded files:",
-    "By uploading files, you agree to the %1$sterms of service%2$s." : "By uploading files, you agree to the %1$sterms of service%2$s.",
     "Share not found" : "Share not found",
     "Back to %s" : "Back to %s",
     "Add to your Nextcloud" : "Add to your Nextcloud",
@@ -263,14 +250,28 @@ OC.L10N.register(
     "This will stop your current uploads." : "This will stop your current uploads.",
     "Move or copy" : "Move or copy",
     "You can upload into this folder" : "You can upload into this folder",
+    "Show list view" : "Show list view",
+    "Show grid view" : "Show grid view",
     "No compatible server found at {remote}" : "No compatible server found at {remote}",
     "Invalid server URL" : "Invalid server URL",
     "Failed to add the public link to your Nextcloud" : "Failed to add the public link to your Nextcloud",
-    "Files" : "ფაილები",
     "Download all files" : "Download all files",
+    "Copy to clipboard" : "Copy to clipboard",
+    "Copy internal link to clipboard" : "Copy internal link to clipboard",
+    "Copy public link of \"{title}\" to clipboard" : "Copy public link of \"{title}\" to clipboard",
+    "Search globally" : "Search globally",
     "Search for share recipients" : "Search for share recipients",
     "No recommendations. Start typing." : "No recommendations. Start typing.",
-    "Allow download" : "Allow download",
-    "Enter your name" : "Enter your name"
+    "Enter your name" : "Enter your name",
+    "Share with {userName}" : "Share with {userName}",
+    "Show sharing options" : "Show sharing options",
+    "Share note" : "Share note",
+    "Upload files to %s" : "Upload files to %s",
+    "Note" : "Note",
+    "Select or drop files" : "Select or drop files",
+    "Uploading files" : "Uploading files",
+    "Uploaded files:" : "Uploaded files:",
+    "By uploading files, you agree to the %1$sterms of service%2$s." : "By uploading files, you agree to the %1$sterms of service%2$s.",
+    "Name" : "სახელი"
 },
 "nplurals=2; plural=(n!=1);");
