@@ -88,6 +88,7 @@ OC.L10N.register(
     "Redo" : "Tee uudelleen",
     "Cannot copy, please copy the link manually" : "Kopioiminen ei onnistu. Kopioi linkki manuaalisesti",
     "Copy link to clipboard" : "Kopioi linkki leikepöydälle",
+    "Open link" : "Avaa linkki",
     "Edit link" : "Muokkaa linkkiä",
     "Save changes" : "Tallenna muutokset",
     "Cancel" : "Peruuta",
@@ -98,6 +99,7 @@ OC.L10N.register(
     "Link to file or folder" : "Linkki tiedostoon tai kansioon",
     "Link to website" : "Linkki verkkosivulle",
     "Update link" : "Päivitä linkki",
+    "{menuItemName}, \"{selectedSubMenuItemName}\" is selected" : "{menuItemName}, \"{selectedSubMenuItemName}\" on valittu",
     "_%n word_::_%n words_" : ["%n sana","%n sanaa"],
     "_%n char_::_%n chars_" : ["%n merkki","%n merkkiä"],
     "Formatting menu bar" : "Muotoiluvalikko",
@@ -152,6 +154,8 @@ OC.L10N.register(
     "Command" : "Komento",
     "Formatting" : "Muotoilu",
     "Select file or folder to link to" : "Valitse tiedosto tai kansio, johon linkitetään",
+    "Choose" : "Valitse",
+    "Choose {file}" : "Valitse {file}",
     "Add folder description" : "Lisään kansion kuvaus",
     "\"{name}\" already exist!" : "\"{name}\" on jo olemassa!",
     "Created \"{name}\"" : "Luotu \"{name}\"",
@@ -161,14 +165,9 @@ OC.L10N.register(
     "Use current version" : "Käytä nykyistä versiota",
     "Use the saved version" : "Käytä tallennettua versiota",
     "Document idle for {timeout} minutes, click to continue editing" : "Dokumentti on ollut käyttämättömänä {timeout} minuuttia, klikkaa jatkaaksesi muokkausta",
-    "Show author colors" : "Näytä tekijän värit",
-    "Author colors are only shown until everyone has closed the document." : "Tekijöiden värit näytetään siihen asti, kunnes kaikki ovat sulkeneet asiakirjan.",
-    "Connection failed." : "Yhteys epäonnistui.",
     "Detect language" : "Havaitse kieli",
     "Info" : "Tietoa",
     "Success" : "Onnistui",
-    "Warning" : "Varoitus",
-    "Control" : "Hallinta",
-    "Add notes, lists or links …" : "Lisää muistiinpanoja, listoja tai linkkejä..."
+    "Warning" : "Varoitus"
 },
 "nplurals=2; plural=(n != 1);");
