@@ -43,16 +43,16 @@ OC.L10N.register(
     "No translation provider available" : "No hay proveedor de traducción disponible",
     "Could not detect language" : "No se pudo detectar el idioma",
     "Unable to translate" : "No se puede traducir",
-    "Nextcloud Server" : "Servidor de Nextcloud",
-    "Some of your link shares have been removed" : "Se han eliminado algunas de sus comparticiones de enlaces",
-    "Due to a security bug we had to remove some of your link shares. Please see the link for more information." : "Debido a un error de seguridad, hemos tenido que eliminar algunas de sus comparticiones de enlaces. Por favor, consulte el enlace para obtener más información.",
-    "Learn more ↗" : "Más información ↗",
-    "Preparing update" : "Preparando actualización",
     "[%d / %d]: %s" : "[%d / %d]: %s ",
     "Repair step:" : "Paso de reparación:",
     "Repair info:" : "Información de reparación:",
     "Repair warning:" : "Advertencia de reparación:",
     "Repair error:" : "Error de reparación:",
+    "Nextcloud Server" : "Servidor de Nextcloud",
+    "Some of your link shares have been removed" : "Se han eliminado algunas de sus comparticiones de enlaces",
+    "Due to a security bug we had to remove some of your link shares. Please see the link for more information." : "Debido a un error de seguridad, hemos tenido que eliminar algunas de sus comparticiones de enlaces. Por favor, consulte el enlace para obtener más información.",
+    "Learn more ↗" : "Más información ↗",
+    "Preparing update" : "Preparando actualización",
     "Please use the command line updater because updating via browser is disabled in your config.php." : "Utilice el actualizador de línea de comandos porque la actualización a través del navegador está deshabilitada en su config.php.",
     "Turned on maintenance mode" : "Modo mantenimiento activado",
     "Turned off maintenance mode" : "Modo mantenimiento desactivado",
@@ -69,6 +69,7 @@ OC.L10N.register(
     "%s (incompatible)" : "%s (incompatible)",
     "The following apps have been disabled: %s" : "Las siguientes aplicaciones se han desactivado: %s",
     "Already up to date" : "Ya está actualizado",
+    "Unknown" : "Desconocido",
     "Error occurred while checking server setup" : "Se presentó un error al verificar la configuración del servidor",
     "For more details see the {linkstart}documentation ↗{linkend}." : "Para obtener más detalles, consulte la {linkstart}documentación ↗{linkend}.",
     "unknown text" : "texto desconocido",
@@ -115,14 +116,14 @@ OC.L10N.register(
     "Password" : "Contraseña",
     "Log in with a device" : "Iniciar sesión con un dispositivo",
     "Your account is not setup for passwordless login." : "Su cuenta no está configurada para iniciar sesión sin contraseña.",
-    "Browser not supported" : "Navegador no compatible",
-    "Passwordless authentication is not supported in your browser." : "La autenticación sin contraseña no es compatible con su navegador.",
     "Your connection is not secure" : "Su conexión no es segura",
     "Passwordless authentication is only available over a secure connection." : "La autenticación sin contraseña solo está disponible a través de una conexión segura.",
+    "Browser not supported" : "Navegador no compatible",
+    "Passwordless authentication is not supported in your browser." : "La autenticación sin contraseña no es compatible con su navegador.",
     "Reset password" : "Restablecer contraseña",
+    "Back to login" : "Regresar al inicio de sesión",
     "Couldn't send reset email. Please contact your administrator." : "No fue posible enviar el correo de restauración. Por favor contacta a tu adminsitrador. ",
     "Password cannot be changed. Please contact your administrator." : "No se puede cambiar la contraseña. Por favor, contacte a su administrador.",
-    "Back to login" : "Regresar al inicio de sesión",
     "New password" : "Nueva contraseña",
     "Your files are encrypted. There will be no way to get your data back after your password is reset. If you are not sure what to do, please contact your administrator before you continue. Do you really want to continue?" : "Sus archivos están cifrados. No habrá forma de recuperar sus datos después de restablecer su contraseña. Si no está seguro de qué hacer, por favor contacte a su administrador antes de continuar. ¿Desea continuar?",
     "I know what I'm doing" : "Sé lo que estoy haciendo",
@@ -164,6 +165,25 @@ OC.L10N.register(
     "Back" : "Atrás",
     "Login form is disabled." : "El formulario de inicio de sesión está desactivado.",
     "More actions" : "Más acciones",
+    "Security warning" : "Advertencia de seguridad",
+    "Storage & database" : "Almacenamiento & base de datos",
+    "Data folder" : "Carpeta de datos",
+    "Install and activate additional PHP modules to choose other database types." : "Instala y activa módulos adicionales de PHP para seleccionar otros tipos de bases de datos. ",
+    "For more details check out the documentation." : "Por favor consulta la documentación para más detalles. ",
+    "Performance warning" : "Advertencia de desempeño",
+    "You chose SQLite as database." : "Elegiste SQLite como base de datos.",
+    "SQLite should only be used for minimal and development instances. For production we recommend a different database backend." : "SQLite solo debe utilizarse para instancias mínimas y de desarrollo. Para producción, recomendamos un backend de base de datos diferente.",
+    "If you use clients for file syncing, the use of SQLite is highly discouraged." : "Si usas clientes para la sincronización de archivos, se desaconseja encarecidamente el uso de SQLite.",
+    "Database user" : "Usuario de la base de datos",
+    "Database password" : "Contraseña de la base de datos",
+    "Database name" : "Nombre de la base de datos",
+    "Database tablespace" : "Espacio de tablas en la base de datos",
+    "Please specify the port number along with the host name (e.g., localhost:5432)." : "Por favor especifica el número de puerto así como el nombre del servidor (ejem., localhost:5432).",
+    "Database host" : "Servidor de base de datos",
+    "Installing …" : "Instalando...",
+    "Install" : "Instalar",
+    "Need help?" : "¿Necesitas ayuda?",
+    "See the documentation" : "Ver la documentación",
     "{name} version {version} and above" : "{name} versión {version} y superior",
     "This browser is not supported" : "Este navegador no es compatible",
     "Your browser is not supported. Please upgrade to a newer version or a supported one." : "Tu navegador no es compatible. Por favor, actualízalo a una versión más nueva o una compatible.",
@@ -201,11 +221,6 @@ OC.L10N.register(
     "Type to search for existing projects" : "Escribe para buscar proyectos existentes",
     "New in" : "Nuevo en",
     "View changelog" : "Ver registro de cambios",
-    "Very weak password" : "Contraseña muy débil",
-    "Weak password" : "Contraseña débil",
-    "So-so password" : "Contraseña aceptable",
-    "Good password" : "Buena contraseña",
-    "Strong password" : "Contraseña fuerte",
     "No action available" : "No hay acciones disponibles",
     "Error fetching contact actions" : "Se presentó un error al traer las acciónes de contatos",
     "Close \"{dialogTitle}\" dialog" : "Cerrar diálogo \"{dialogTitle}\"",
@@ -221,9 +236,9 @@ OC.L10N.register(
     "Admin" : "Administración",
     "Help" : "Ayuda",
     "Access forbidden" : "Acceso prohibido",
+    "Back to %s" : "Volver a %s",
     "Page not found" : "Página no encontrada",
     "The page could not be found on the server or you may not be allowed to view it." : "No se pudo encontrar la página en el servidor o es posible que no se te permita verla.",
-    "Back to %s" : "Volver a %s",
     "Too many requests" : "Demasiadas solicitudes",
     "There were too many requests from your network. Retry later or contact your administrator if this is an error." : "Había demasiadas solicitudes desde tu red. Vuelve a intentarlo más tarde o contacta a tu administrador si se trata de un error.",
     "Error" : "Error",
@@ -240,30 +255,6 @@ OC.L10N.register(
     "File: %s" : "Archivo: %s",
     "Line: %s" : "Línea: %s",
     "Trace" : "Rastrear",
-    "Security warning" : "Advertencia de seguridad",
-    "Your data directory and files are probably accessible from the internet because the .htaccess file does not work." : "Tu directorio de datos y sus archivos probablemente sean accesibles desde Internet ya que el archivo .htaccess no funciona.",
-    "For information how to properly configure your server, please see the <a href=\"%s\" target=\"_blank\" rel=\"noreferrer noopener\">documentation</a>." : "Para más información de como configurar correctaemente tu servidor, por favor consulta la <a href=\"%s\" target=\"_blank\" rel=\"noreferrer noopener\">documentación</a>.",
-    "Show password" : "Mostrar contraseña",
-    "Toggle password visibility" : "Alternar visibilidad de contraseña",
-    "Storage & database" : "Almacenamiento & base de datos",
-    "Data folder" : "Carpeta de datos",
-    "Configure the database" : "Configurar la base de datos",
-    "Only %s is available." : "Sólo %s está disponible.",
-    "Install and activate additional PHP modules to choose other database types." : "Instala y activa módulos adicionales de PHP para seleccionar otros tipos de bases de datos. ",
-    "For more details check out the documentation." : "Por favor consulta la documentación para más detalles. ",
-    "Database password" : "Contraseña de la base de datos",
-    "Database name" : "Nombre de la base de datos",
-    "Database tablespace" : "Espacio de tablas en la base de datos",
-    "Database host" : "Servidor de base de datos",
-    "Please specify the port number along with the host name (e.g., localhost:5432)." : "Por favor especifica el número de puerto así como el nombre del servidor (ejem., localhost:5432).",
-    "Performance warning" : "Advertencia de desempeño",
-    "You chose SQLite as database." : "Elegiste SQLite como base de datos.",
-    "SQLite should only be used for minimal and development instances. For production we recommend a different database backend." : "SQLite solo debe utilizarse para instancias mínimas y de desarrollo. Para producción, recomendamos un backend de base de datos diferente.",
-    "If you use clients for file syncing, the use of SQLite is highly discouraged." : "Si usas clientes para la sincronización de archivos, se desaconseja encarecidamente el uso de SQLite.",
-    "Install" : "Instalar",
-    "Installing …" : "Instalando...",
-    "Need help?" : "¿Necesitas ayuda?",
-    "See the documentation" : "Ver la documentación",
     "It looks like you are trying to reinstall your Nextcloud. However the file CAN_INSTALL is missing from your config directory. Please create the file CAN_INSTALL in your config folder to continue." : "Parece que estás intentando reinstalar tu Nextcloud. Sin embargo, falta el archivo CAN_INSTALL en tu directorio de configuración. Crea el archivo CAN_INSTALL en tu carpeta de configuración para continuar.",
     "Could not remove CAN_INSTALL from the config folder. Please remove this file manually." : "No se pudo eliminar CAN_INSTALL de la carpeta de configuración. Elimina este archivo manualmente.",
     "This application requires JavaScript for correct operation. Please {linkstart}enable JavaScript{linkend} and reload the page." : "Esta aplicación requiere de JavaScript para su correcta operación. Por favor {linkstart}habilita JavaScript{linkend} y vuelve a cargar la página. ",
@@ -319,15 +310,24 @@ OC.L10N.register(
     "This %s instance is currently in maintenance mode, which may take a while." : "Esta instancia %s se encuentra actualmente en modo mantenimiento, que podría tomar algo de tiempo. ",
     "This page will refresh itself when the instance is available again." : "Esta página se actualizará automáticamente cuando la instancia esté disponible nuevamente.",
     "Contact your system administrator if this message persists or appeared unexpectedly." : "Contacta a tu administrador del sistema si este mensaje persiste o se presentó de manera inesperada.",
-    "Currently open" : "Actualmente abierto",
     "Chatting, video calls, screensharing, online meetings and web conferencing – in your browser and with mobile apps." : "Chat, videollamadas, uso compartido de pantalla, reuniones en línea y videoconferencias, en tu navegador y con aplicaciones móviles.",
     "You have not added any info yet" : "No has agregado ninguna información todavía",
     "{user} has not added any info yet" : "{user} no ha agregado ninguna información aún",
     "Error opening the user status modal, try hard refreshing the page" : "Error al abrir el modal de estado del usuario, intenta actualizar la página",
     "Edit Profile" : "Editar perfil",
     "The headline and about sections will show up here" : "El titular y la sección Acerca de se mostrarán aquí",
-    "Error loading message template: {error}" : "Se presentó un error al cargar la plantilla del mensaje: {error}",
+    "Very weak password" : "Contraseña muy débil",
+    "Weak password" : "Contraseña débil",
+    "So-so password" : "Contraseña aceptable",
+    "Good password" : "Buena contraseña",
+    "Strong password" : "Contraseña fuerte",
     "Profile not found" : "Perfil no encontrado",
-    "The profile does not exist." : "El perfil no existe."
+    "The profile does not exist." : "El perfil no existe.",
+    "Your data directory and files are probably accessible from the internet because the .htaccess file does not work." : "Tu directorio de datos y sus archivos probablemente sean accesibles desde Internet ya que el archivo .htaccess no funciona.",
+    "For information how to properly configure your server, please see the <a href=\"%s\" target=\"_blank\" rel=\"noreferrer noopener\">documentation</a>." : "Para más información de como configurar correctaemente tu servidor, por favor consulta la <a href=\"%s\" target=\"_blank\" rel=\"noreferrer noopener\">documentación</a>.",
+    "Show password" : "Mostrar contraseña",
+    "Toggle password visibility" : "Alternar visibilidad de contraseña",
+    "Configure the database" : "Configurar la base de datos",
+    "Only %s is available." : "Sólo %s está disponible."
 },
 "nplurals=3; plural=n == 1 ? 0 : n != 0 && n % 1000000 == 0 ? 1 : 2;");
