@@ -51,6 +51,11 @@ OC.L10N.register(
     "No translation provider available" : "No hay proveedores de traducción disponibles",
     "Could not detect language" : "No se pudo detectar el idioma",
     "Unable to translate" : "No se puede traducir",
+    "[%d / %d]: %s" : "[%d / %d]: %s ",
+    "Repair step:" : "Paso de reparación:",
+    "Repair info:" : "Información de reparación:",
+    "Repair warning:" : "Advertencia de reparación:",
+    "Repair error:" : "Error de reparación: ",
     "Nextcloud Server" : "Servidor Nextcloud",
     "Some of your link shares have been removed" : "Se han eliminado algunos de sus enlaces compartidos",
     "Due to a security bug we had to remove some of your link shares. Please see the link for more information." : "Debido a un error de seguridad, tuvimos que eliminar algunos de sus enlaces compartidos. Por favor vea el enlace para más información.",
@@ -58,11 +63,6 @@ OC.L10N.register(
     "Enter your subscription key in the support app in order to increase the account limit. This does also grant you all additional benefits that Nextcloud Enterprise offers and is highly recommended for the operation in companies." : "Ingrese su clave de suscripción en la aplicación de soporte para aumentar el límite de cuentas. Esto también le otorga todos los beneficios adicionales que ofrece Nextcloud Enterprise y que es altamente recomendado para la operación en empresas.",
     "Learn more ↗" : "Más información ↗",
     "Preparing update" : "Preparando actualización",
-    "[%d / %d]: %s" : "[%d / %d]: %s ",
-    "Repair step:" : "Paso de reparación:",
-    "Repair info:" : "Información de reparación:",
-    "Repair warning:" : "Advertencia de reparación:",
-    "Repair error:" : "Error de reparación: ",
     "Please use the command line updater because updating via browser is disabled in your config.php." : "Por favor, utilice el actualizador desde la línea de comandos porque la actualización a través del navegador está deshabilitada en config.php.",
     "Turned on maintenance mode" : "Modo mantenimiento activado",
     "Turned off maintenance mode" : "Modo mantenimiento desactivado",
@@ -79,6 +79,8 @@ OC.L10N.register(
     "%s (incompatible)" : "%s (incompatible)",
     "The following apps have been disabled: %s" : "Las siguientes aplicaciones han sido deshabilitadas: %s",
     "Already up to date" : "Ya está actualizado",
+    "Unknown" : "Desconocido",
+    "PNG image" : "Imagen PNG",
     "Error occurred while checking server setup" : "Se presentó un error al verificar la configuración del servidor",
     "For more details see the {linkstart}documentation ↗{linkend}." : "Para más detalles, consulte la {linkstart}documentación ↗{linkend}.",
     "unknown text" : "texto desconocido",
@@ -109,7 +111,6 @@ OC.L10N.register(
     "Federated user" : "Usuario federado",
     "user@your-nextcloud.org" : "usuario@su-nextcloud.org",
     "Create share" : "Crear recurso compartido",
-    "Direct link copied to clipboard" : "Enlace directo copiado al portapapeles",
     "Please copy the link manually:" : "Por favor, copie el enlace manualmente:",
     "Custom date range" : "Rango de fechas personalizado",
     "Pick start date" : "Elegir una fecha de inicio",
@@ -146,8 +147,6 @@ OC.L10N.register(
     "Account name" : "Nombre de cuenta",
     "Server side authentication failed!" : "¡Falló la autenticación del lado del servidor!",
     "Please contact your administrator." : "Por favor contacta al administrador.",
-    "Temporary error" : "Error temporal",
-    "Please try again." : "Por favor, inténtelo de nuevo",
     "An internal error occurred." : "Se presentó un error interno.",
     "Please try again or contact your administrator." : "Por favor vuelve a intentarlo o contacta a tu adminsitrador. ",
     "Password" : "Contraseña",
@@ -283,9 +282,9 @@ OC.L10N.register(
     "Admin" : "Administración",
     "Help" : "Ayuda",
     "Access forbidden" : "Acceso prohibido",
+    "Back to %s" : "Volver a %s",
     "Page not found" : "Página no encontrada",
     "The page could not be found on the server or you may not be allowed to view it." : "No se pudo encontrar la página en el servidor o es posible que no se le permita verla.",
-    "Back to %s" : "Volver a %s",
     "Too many requests" : "Demasiadas solicitudes",
     "There were too many requests from your network. Retry later or contact your administrator if this is an error." : "Hubieron demasiadas solicitudes desde su red. Vuelva a intentarlo más tarde o contacte a su administrador si se trata de un error.",
     "Error" : "Error",
@@ -361,16 +360,12 @@ OC.L10N.register(
     "This %s instance is currently in maintenance mode, which may take a while." : "Esta instancia %s se encuentra actualmente en modo mantenimiento, que podría tomar algo de tiempo. ",
     "This page will refresh itself when the instance is available again." : "Esta página se actualizará automáticamente cuando la instancia esté disponible nuevamente.",
     "Contact your system administrator if this message persists or appeared unexpectedly." : "Contacta a tu administrador del sistema si este mensaje persiste o se presentó de manera inesperada.",
-    "Currently open" : "Actualmente abierto",
-    "Login with username or email" : "Iniciar sesión con nombre de usuario o correo electrónico",
-    "Login with username" : "Iniciar sesión con nombre de usuario",
     "Chatting, video calls, screensharing, online meetings and web conferencing – in your browser and with mobile apps." : "Mensajes, videollamadas, compartir pantalla, reuniones en línea y conferencias web – en su navegador y aplicaciones móviles.",
     "You have not added any info yet" : "Aún no has añadido información",
     "{user} has not added any info yet" : "{user} aún no añade información",
     "Error opening the user status modal, try hard refreshing the page" : "Error al abrir la ventana de estado del usuario, intente actualizar la página",
     "Edit Profile" : "Editar perfil",
     "The headline and about sections will show up here" : "El encabezado y la sección Acerca de aparecerán aquí",
-    "Error loading message template: {error}" : "Se presentó un error al cargar la plantilla del mensaje: {error}",
     "Very weak password" : "Contraseña muy débil",
     "Weak password" : "Contraseña débil",
     "So-so password" : "Contraseña aceptable",
@@ -384,6 +379,7 @@ OC.L10N.register(
     "Toggle password visibility" : "Alternar visibilidad de la contraseña",
     "Configure the database" : "Configurar la base de datos",
     "Only %s is available." : "Sólo %s está disponible.",
-    "Database account" : "Cuenta de la base de datos"
+    "Database account" : "Cuenta de la base de datos",
+    "Direct link copied to clipboard" : "Enlace directo copiado al portapapeles"
 },
 "nplurals=3; plural=n == 1 ? 0 : n != 0 && n % 1000000 == 0 ? 1 : 2;");
