@@ -196,8 +196,6 @@ OC.L10N.register(
     "Cannot write into \"config\" directory." : "Kan niet schrijven naar de \"config\" directory!",
     "This can usually be fixed by giving the web server write access to the config directory. See %s" : "Dit kan opgelost worden door de config map op de webserver schrijf rechten te geven. Zie %s",
     "Or, if you prefer to keep config.php file read only, set the option \"config_is_read_only\" to true in it. See %s" : "Of, als je liever config.php Alleen-lezen houdt, stel de optie  \"config_is_read_only\" in op true. Zie %s",
-    "Cannot write into \"apps\" directory." : "Kan niet schrijven naar de \"apps\" directory",
-    "This can usually be fixed by giving the web server write access to the apps directory or disabling the App Store in the config file." : "Dit kan hersteld worden door de webserver schrijfrechten te geven op de appsdirectory of door de App Store te deactiveren in het configuratie bestand.",
     "Cannot create \"data\" directory." : "Kan de \"data\"-map niet aanmaken.",
     "This can usually be fixed by giving the web server write access to the root directory. See %s" : "Dit kan hersteld worden door de root map schrijf rechten te geven op de webserver. Zie %s",
     "Permissions can usually be fixed by giving the web server write access to the root directory. See %s." : "Machtigingen kunnen worden hersteld door de root map op de webserver schrijf toegang te geven. Zie %s.",
@@ -236,6 +234,8 @@ OC.L10N.register(
     "Translate" : "Vertaal",
     "Result" : "Resultaat",
     "Organisation" : "Organisatie",
-    "File is currently busy, please try again later" : "Bestandsverwerking bezig, probeer het later opnieuw"
+    "File is currently busy, please try again later" : "Bestandsverwerking bezig, probeer het later opnieuw",
+    "Cannot write into \"apps\" directory." : "Kan niet schrijven naar de \"apps\" directory",
+    "This can usually be fixed by giving the web server write access to the apps directory or disabling the App Store in the config file." : "Dit kan hersteld worden door de webserver schrijfrechten te geven op de appsdirectory of door de App Store te deactiveren in het configuratie bestand."
 },
 "nplurals=2; plural=(n != 1);");
