@@ -142,7 +142,6 @@ OC.L10N.register(
     "About" : "O aplikácii",
     "Display name" : "Zobrazované meno",
     "Headline" : "Titul",
-    "Organisation" : "Organizácia",
     "Role" : "Rola",
     "Pronouns" : "Zámená",
     "Unknown account" : "Neznámy účet",
@@ -284,8 +283,6 @@ OC.L10N.register(
     "Cannot write into \"config\" directory." : "Nie je možné zapisovať do priečinka \"config\".",
     "This can usually be fixed by giving the web server write access to the config directory. See %s" : "To je zvyčajne možné opraviť tým, že udelíte webovému serveru oprávnenie na zápis do adresára s konfiguráciou. Viď %s",
     "Or, if you prefer to keep config.php file read only, set the option \"config_is_read_only\" to true in it. See %s" : "Alebo, ak preferujete ponechať súbor config.php iba na čítanie, nastavte v ňom parameter \"config_is_read_only\" na true.  Viď %s",
-    "Cannot write into \"apps\" directory." : "Nie je možné zapisovať do priečinka \"apps\".",
-    "This can usually be fixed by giving the web server write access to the apps directory or disabling the App Store in the config file." : "Toto sa zvyčajne dá opraviť poskytnutím práva webového servera na zápis do priečinka s aplikáciami alebo vypnutím katalógu s aplikáciami v súbore s nastaveniami.",
     "Cannot create \"data\" directory." : "Nie je možné vytvoriť priečinok \"data\"",
     "This can usually be fixed by giving the web server write access to the root directory. See %s" : "To je zvyčajne možné opraviť tým, že udelíte webovému serveru oprávnenie na zápis do koreňového adresára. Viď %s",
     "Permissions can usually be fixed by giving the web server write access to the root directory. See %s." : "Oprávnenia je zvyčajne možné opraviť tým, že udelíte webovému serveru oprávnenie na zápis do koreňového priečinka. Viď %s.",
@@ -322,26 +319,30 @@ OC.L10N.register(
     "Storage is temporarily not available" : "Úložisko je dočasne nedostupné",
     "Storage connection timeout. %s" : "Vypršanie pripojenia k úložisku. %s",
     "To allow this check to run you have to make sure that your Web server can connect to itself. Therefore it must be able to resolve and connect to at least one of its `trusted_domains` or the `overwrite.cli.url`. This failure may be the result of a server-side DNS mismatch or outbound firewall rule." : "Ak chcete povoliť spustenie tejto kontroly, musíte sa uistiť, že váš webový server sa môže pripojiť sám k sebe. Preto musí byť schopný rozpoznať a pripojiť sa aspoň k jednej zo svojich `trusted_domains` alebo `overwrite.cli.url`.  Výsledkom nesprávneho nastavenia môže byť nesúlad DNS na strane servera alebo pravidla brány firewall pre výstup.",
+    "Images" : "Obrázky",
+    "Question" : "Otázka",
+    "Generated response" : "Vygenerovaná odpoveď",
+    "System prompt" : "Systémová výzva",
+    "Define rules and assumptions that the assistant should follow during the conversation." : "Definovať pravidlá a predpoklady, ktoré by mal asistent počas rozhovoru dodržiavať.",
+    "Chat history" : "História chatu",
     "Transcribe audio" : "Prepísať zvuk",
     "Transcribe the things said in an audio" : "Prepísať veci povedané vo zvuku",
     "Audio input" : "Audio vstup",
     "The audio to transcribe" : "Zvuk pre prepísanie",
     "Transcription" : "Prepis",
     "The transcribed text" : "Prepísaný text",
-    "ContextAgent" : "ContextAgent",
-    "Chat with an agent" : "Čet s agentom",
-    "Chat message" : "Správa chatu",
-    "A chat message to send to the agent." : "Správa četu pre poslanie agentovi.",
     "Confirmation" : "Potvrdenie",
     "Whether to confirm previously requested actions: 0 for denial and 1 for confirmation." : "Či potvrdiť predtým požadované akcie: 0 pre odmietnutie a 1 pre potvrdenie.",
     "Conversation token" : "Token konverzácie",
     "A token representing the conversation." : "Token reprezentujúci konverzáciu.",
-    "Generated response" : "Vygenerovaná odpoveď",
-    "The response from the chat model." : "Odpoveď z modelu četu.",
     "The new conversation token" : "Nový token konverzácie",
     "Send this along with the next interaction." : "Odoslať to spolu s ďalšou interakciou.",
     "Requested actions by the agent" : "Vyžiadané akcie agentom",
     "Actions that the agent would like to carry out in JSON format." : "Akcie, ktoré by chcel agent vykonať vo formáte JSON.",
+    "Chat with an agent" : "Čet s agentom",
+    "Chat message" : "Správa chatu",
+    "A chat message to send to the agent." : "Správa četu pre poslanie agentovi.",
+    "The response from the chat model." : "Odpoveď z modelu četu.",
     "Context write" : "Kontextový zápis",
     "Writes text in a given style based on the provided source material." : "Napíše text v danom štýle na základe poskytnutého zdrojového materiálu.",
     "Writing style" : "Štýl písania",
@@ -376,9 +377,6 @@ OC.L10N.register(
     "The rewritten text in the desired tone, written by the assistant:" : "Prepísaný text v požadovanom tóne, napísaný asistentom:",
     "Chat" : "Chat",
     "Chat with the assistant" : "Chat s asistentom",
-    "System prompt" : "Systémová výzva",
-    "Define rules and assumptions that the assistant should follow during the conversation." : "Definovať pravidlá a predpoklady, ktoré by mal asistent počas rozhovoru dodržiavať.",
-    "Chat history" : "História chatu",
     "The history of chat messages before the current message, starting with a message by the user" : "História četových správ pred aktuálnou správou, počnúc správou od užívateľa",
     "Response message" : "Správa s odpoveďou",
     "The generated response as part of the conversation" : "Vygenerovaná odpoveď ako súčasť konverzácie",
@@ -442,21 +440,10 @@ OC.L10N.register(
     "Generate headline" : "Generovať nadpis",
     "Summarizes text by reducing its length without losing key information." : "Zhrňuje text tým, že znižuje jeho dĺžku bez straty kľúčových informácií.",
     "Extracts topics from a text and outputs them separated by commas." : "Extrahuje témy z textu a vypisuje ich oddelené čiarkami.",
-    "Education Edition" : "Edícia pre výuku",
-    "File name is a reserved word" : "Názov súboru je rezervované slovo.",
-    "File name contains at least one invalid character" : "Názov súboru obsahuje nepovolené znaky.",
-    "File name is too long" : "Meno súboru je veľmi dlhé.",
-    "Users" : "Používatelia",
-    "%1$s shared »%2$s« with you and wants to add:" : "%1$s vám sprístupnil »%2$s« s poznámkou:",
-    "%1$s shared »%2$s« with you and wants to add" : "%1$s vám sprístupnil »%2$s« s poznámkou",
-    "»%s« added a note to a file shared with you" : "»%s« pridal poznámku k súboru ktorý s Vami zdieľa",
-    "Open »%s«" : "Otvoriť »%s«",
-    "%1$s shared »%2$s« with you" : "%1$s vám sprístupnil »%2$s«",
-    "%1$s shared »%2$s« with you." : "%1$s vám sprístupnil »%2$s«.",
-    "Click the button below to open it." : "Pre otvorenie klienta kliknite na tlačítko nižšie.",
+    "Organisation" : "Organizácia",
     "File is currently busy, please try again later" : "Súbor sa práve používa, skúste prosím neskôr",
     "Cannot download file" : "Nemožno stiahnuť súbor",
-    "Ensure there is a file called \".ocdata\" in the root of the data directory." : "Uistite sa, že v koreňovom adresári sa nachádza súbor s názvom \".ocdata\".",
-    "Path contains files shared with you" : "Cesta obsahuje súbory zdieľané s vami"
+    "Cannot write into \"apps\" directory." : "Nie je možné zapisovať do priečinka \"apps\".",
+    "This can usually be fixed by giving the web server write access to the apps directory or disabling the App Store in the config file." : "Toto sa zvyčajne dá opraviť poskytnutím práva webového servera na zápis do priečinka s aplikáciami alebo vypnutím katalógu s aplikáciami v súbore s nastaveniami."
 },
 "nplurals=4; plural=(n % 1 == 0 && n == 1 ? 0 : n % 1 == 0 && n >= 2 && n <= 4 ? 1 : n % 1 != 0 ? 2: 3);");
