@@ -97,8 +97,8 @@ class AppConfig implements IAppConfig {
 	 * @inheritDoc
 	 *
 	 * @param string $app id of the app
-	 *
 	 * @return list<string> list of stored config keys
+	 *
 	 * @since 29.0.0
 	 */
 	public function getKeys(string $app): array {
@@ -110,6 +110,33 @@ class AppConfig implements IAppConfig {
 		return array_values(array_unique($keys));
 	}
 
+	/**
+	 * @inheritDoc
+	 *
+	 * @param string $app id of the app
+	 * @param string $prefix returns only keys starting with this value
+	 * @param bool $lazy TRUE to search in lazy config keys
+	 * @return list<string> list of stored config keys
+	 * @since 32.0.0
+	 * @internal not publicly available before 32.
+	 */
+	public function searchKeys(string $app, string $prefix = '', bool $lazy = false): array {
+		$this->assertParams($app);
+		$this->loadConfig($app, $lazy);
+		if ($lazy) {
+			$keys = array_keys($this->lazyCache[$app] ?? []);
+		} else {
+			$keys = array_keys($this->fastCache[$app] ?? []);
+		}
+
+		if ($prefix !== '') {
+			$keys = array_filter($keys, static fn (string $key): bool => str_starts_with($key, $prefix));
+		}
+
+		sort($keys);
+		return array_values(array_unique($keys));
+	}
+
 	/**
 	 * @inheritDoc
 	 *
@@ -1455,6 +1482,9 @@ class AppConfig implements IAppConfig {
 			'globalsiteselector' => [
 				'/^gss\.jwt\.key$/',
 			],
+			'gpgmailer' => [
+				'/^GpgServerKey$/',
+			],
 			'integration_discourse' => [
 				'/^private_key$/',
 				'/^public_key$/',
@@ -1509,6 +1539,9 @@ class AppConfig implements IAppConfig {
 				'/^client_secret$/',
 				'/^oauth_instance_url$/',
 			],
+			'maps' => [
+				'/^mapboxAPIKEY$/',
+			],
 			'notify_push' => [
 				'/^cookie$/',
 			],
@@ -1546,12 +1579,12 @@ class AppConfig implements IAppConfig {
 				'/^slogan$/',
 				'/^url$/',
 			],
-			'user_ldap' => [
-				'/^(s..)?ldap_agent_password$/',
-			],
 			'twofactor_gateway' => [
 				'/^.*token$/',
 			],
+			'user_ldap' => [
+				'/^(s..)?ldap_agent_password$/',
+			],
 			'user_saml' => [
 				'/^idp-x509cert$/',
 			],
